package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See F<LICENSE>.

=cut

$^V eq 5.26.3 
    or die sprintf("Perl (%s) version (%vd) doesn't match the version (5.26.3) ".
                   "that PAR::Packer was built with; please rebuild PAR::Packer", 
                   $^X, $^V);

1;

__DATA__
M?T5,1@(!`0````````````,`/@`!````KB4```````!``````````#"Q````
M`````````$``.``*`$``&``7``8````$````0`````````!``````````$``
M````````,`(````````P`@````````@``````````P````0```!P`@``````
M`'`"````````<`(````````9`````````!D``````````0`````````!````
M!````````````````````````````````````$`8````````0!@`````````
M$`````````$````%`````"``````````(``````````@````````=#0`````
M``!T-``````````0`````````0````0`````8`````````!@`````````&``
M```````\1````````#Q$`````````!`````````!````!@```/"K````````
M\+L```````#PNP```````'`$````````&!4`````````$`````````(````&
M````.*P````````XO````````#B\````````H`$```````"@`0````````@`
M````````4.5T9`0````DGP```````"2?````````))\```````#,````````
M`,P`````````!`````````!1Y71D!@``````````````````````````````
M```````````````````````````0`````````%+E=&0$````\*L```````#P
MNP```````/"[````````$`0````````0!`````````$`````````+VQI8B]L
M9"UM=7-L+7@X-E\V-"YS;RXQ```````````1````0@````0````(````(`P`
M``5`!((H`%``D(8`@((A`"!)`@0)N((92;H$!@I"````0P```$<```!+````
M3````%(```!3````50````````!9`````````%H```!<````7@```%\`````
M`````````*/I&01J?YI\ZM/O#L[>1RUOQ=\?+L6;MKB-\0[49-1\(?_D#MEQ
M6!SZH6Q@PN4_++(!BV_RV],=XD?&`;OCDGQ5PSS2Q+F<0&>OS&8X\HL<Q(D%
MD(@'<--#1=7L,V+;[5:DFY:GW:-K?JF<F]%ESFWAIP(*"HH05Z/@^TD`````
M```````````````````````````,````$@````````````````````````"Z
M`0``$@````````````````````````!<`0``$@``````````````````````
M```;````$@````````````````````````"9`0``$@``````````````````
M```````C````$@`````````````````````````J````$@``````````````
M``````````#M`0``$@````````````````````````"E`0``$@``````````
M```````````````S````(`````````````````````````!+````$@``````
M``````````````````!1````$@````````````````````````!8````$@``
M``````````````````````#\`@``$@````````````````````````#M`@``
M$@````````````````````````!R`@``$@````````````````````````!?
M````$@`````````````````````````3`@``$@``````````````````````
M``!F````$@````````````````````````"G`@``$@``````````````````
M``````!M````$@````````````````````````!U````$@``````````````
M``````````"0`@``$@````````````````````````!]````$@``````````
M``````````````"#````$@````````````````````````",````(```````
M``````````````````#F`@``$@````````````````````````"H````$@``
M``````````````````````"M````$@````````````````````````"N`@``
M$@````````````````````````!``@``$@`````````````````````````,
M`P``$@`````````````````````````R`@``$@``````````````````````
M``!:`P``$@````````````````````````!D`@``$@``````````````````
M```````B`P``$@````````````````````````"T````$@``````````````
M```````````:`P``$@````````````````````````!J`0``$@``````````
M``````````````#,````(`````````````````````````#B````$@``````
M``````````````````#>`@``$@````````````````````````!0`@``$@``
M``````````````````````#G````$@````````````````````````#M````
M(`````````````````````````";`@``$@`````````````````````````'
M`0``$@````````````````````````"*`0``$@``````````````````````
M```,`0``$@````````````````````````"``@``$@``````````````````
M``````!Y`0``$@`````````````````````````2`0``$@``````````````
M```````````C`0``$@`````````````````````````.`@``$@``````````
M``````````````!^````$@`````````````````````````?`@``$@``````
M``````````````````!9`@``$@`````````````````````````3`P``$@``
M```````````````````````I`0``$@`````````````````````````$`P``
M$@`````````````````````````]`0``$@`````````````````````````)
M`@``$@````````````````````````#(`0``$@``````````````````````
M``!$`0``$@````````````````````````!5`0``$@``````````````````
M```````T`P``(0`5`&C`````````"``````````O`P``$@`*`-@C````````
MU@$```````#:`0``$@`+`&Q4`````````0````````"<`P``$@`*`!5(````
M````FP@````````J!```$@`*`/Q3````````3@````````!Y`P``$@`*``U#
M````````!0````````"K`P``$@`'```@`````````0````````"_`P``$@`*
M`+!0````````3`,````````8!```$@`*`!)#````````M`$```````#L`P``
M$``5`&#```````````````````"*`P``$@`*`']'````````E@````````"I
M`P``$@`*`*-!````````*P````````"Q`P``$@`*`!]'````````1```````
M``"Y`@``$0`1`""\````````$P````````#?`P``$@`*`,9$````````%@``
M```````E!```$``5``C1```````````````````_`P``$@`*`,0E````````
M)0`````````U`P``$0`5`&C`````````"`````````#X`P``$@`*`-Q$````
M````GP`````````4````$0`1`!"\````````"``````````V`P``(0`5`&C`
M````````"`````````#5`P``$0`4`%C`````````"``````````1!```$``4
M`&#```````````````````#Q`P``$``*`*XE``````````````````#^`0``
M$0`5`'#`````````!``````````W`P``(0`5`&C`````````"`````````!(
M`P``$@`*`&-'````````'`````````"]````(@``````````````````````
M``!C`P``$@`*`!)"````````^P````````#@`0``$0`5`&#``````````0``
M```````$!```$@`*`'M%````````I`$`````````;&EB<&5R;"YS;P!O<&5N
M9&ER`'-T9&5R<@!R96%L;&]C`&%C8V5S<P!S;G!R:6YT9@!?7V1E<F5G:7-T
M97)?9G)A;65?:6YF;P!L<V5E:P!G971P:60`<W1R8VUP`&UE;7-E=`!U;FQI
M;FL`;65M;6]V90!S=')N8VUP`&QS=&%T`&-L;W-E9&ER`%])5$U?9&5R96=I
M<W1E<E1-0VQO;F5486)L90!O<&5N`'-T<G-T<@!R96%D;&EN:P!?7V-X85]F
M:6YA;&EZ90!?7W)E9VES=&5R7V9R86UE7VEN9F\`97AI=`!C;&]S90!?251-
M7W)E9VES=&5R5$U#;&]N951A8FQE`')E860`<FUD:7(`7U]E<G)N;U]L;V-A
M=&EO;@!M:V1I<@!P=&AR96%D7V=E='-P96-I9FEC`&UE;6-P>0!?7W-T86-K
M7V-H:U]F86EL`&=E='5I9`!097)L7W-Y<U]T97)M`%!E<FQ?<WES7VEN:70S
M`%!E<FQ?871F;W)K7VQO8VL`<&5R;%]C;VYS=')U8W0`4&5R;%]G971?<W8`
M4&5R;%]C<F]A:U]N;V-O;G1E>'0`4&5R;%]A=E]S:&EF=`!097)L7W-V7S)P
M=E]F;&%G<P!?9FEN:0!03%]D;U]U;F1U;7``4&5R;%]N97=84U]F;&%G<P!0
M3%]T:')?:V5Y`'!E<FQ?9G)E90!097)L7VUG7W-E=`!097)L7V%T9F]R:U]U
M;FQO8VL`4&5R;%]S=E]S971P=@!097)L7V=V7V9E=&-H<'8`<&5R;%]R=6X`
M4&5R;%]N97=84P!P97)L7V1E<W1R=6-T`%!E<FQ?879?9F5T8V@`8F]O=%]$
M>6YA3&]A9&5R`'!E<FQ?<&%R<V4`4&5R;%]S869E<WES;6%L;&]C`'!E<FQ?
M86QL;V,`4$Q?;65M;W)Y7W=R87``;&EB8RYM=7-L+7@X-E\V-"YS;RXQ`&9P
M<FEN=&8`<W1R9'5P`'!T:')E861?871F;W)K`')E861D:7(`<W!R:6YT9@!S
M=')C:'(`<W1R=&]K`'-T<FYC<'D`7U]L:6)C7W-T87)T7VUA:6X`7U]?96YV
M:7)O;@!?<W1A<G1?8P!G971?=7-E<FYA;65?9G)O;5]G971P=W5I9`!P87)?
M8W5R<F5N=%]E>&5C7W!R;V,`<&%R7V-U<G)E;G1?97AE8P!P87)?<V5T=7!?
M;&EB<&%T:`!P87)?;6MT;7!D:7(`>'-?:6YI=`!P87)?96YV7V-L96%N`%A3
M7TEN=&5R;F%L<U]005)?0D]/5`!M>5]P87)?<&P`<&%R7V)A<V5N86UE`%]?
M8G-S7W-T87)T`'!A<E]D:7)N86UE`'!A<E]I;FET7V5N=@!?961A=&$`<&%R
M7V9I;F1P<F]G`%]E;F0`<&%R7V-L96%N=7``+W5S<B]L:6(O<&5R;#4O8V]R
M95]P97)L+T-/4D4```````#`````````"```````````P````````"#`````
M````"`````````#B8````````"C`````````"`````````#;8````````##`
M````````"``````````>8@```````#C`````````"`````````#X8```````
M`$#`````````"``````````F8@```````%C`````````"`````````"[8@``
M`````,"_````````!@````H``````````````,B_````````!@```!H`````
M`````````-"_````````!@```%T``````````````-B_````````!@```"@`
M`````````````."_````````!@```"T``````````````.B_````````!@``
M`#(``````````````/"_````````!@```#,``````````````/B_````````
M!@```#@``````````````!"\````````!0```%4``````````````""\````
M````!0```$\``````````````&#`````````!0```%\``````````````&C`
M````````!0```%,``````````````'#`````````!0```%H`````````````
M`/"]````````!P````$``````````````/B]````````!P````(`````````
M``````"^````````!P````,```````````````B^````````!P````0`````
M`````````!"^````````!P````4``````````````!B^````````!P````8`
M`````````````""^````````!P````<``````````````"B^````````!P``
M``@``````````````#"^````````!P````D``````````````#B^````````
M!P````L``````````````$"^````````!P````P``````````````$B^````
M````!P````T``````````````%"^````````!P````X``````````````%B^
M````````!P````\``````````````&"^````````!P```!``````````````
M`&B^````````!P```!$``````````````'"^````````!P```!(`````````
M`````'B^````````!P```!,``````````````("^````````!P```!0`````
M`````````(B^````````!P```!4``````````````)"^````````!P```!8`
M`````````````)B^````````!P```!<``````````````*"^````````!P``
M`!@``````````````*B^````````!P```!D``````````````+"^````````
M!P```!L``````````````+B^````````!P```!P``````````````,"^````
M````!P```!T``````````````,B^````````!P```!X``````````````-"^
M````````!P```!\``````````````-B^````````!P```"``````````````
M`."^````````!P```"$``````````````.B^````````!P```"(`````````
M`````/"^````````!P```",``````````````/B^````````!P```"0`````
M``````````"_````````!P```"4```````````````B_````````!P```"8`
M`````````````!"_````````!P```"<``````````````!B_````````!P``
M`"D``````````````""_````````!P```"H``````````````"B_````````
M!P```"L``````````````#"_````````!P```"P``````````````#B_````
M````!P```"X``````````````$"_````````!P```"\``````````````$B_
M````````!P```#```````````````%"_````````!P```#$`````````````
M`%B_````````!P```#0``````````````&"_````````!P```#4`````````
M`````&B_````````!P```#8``````````````'"_````````!P```#<`````
M`````````'B_````````!P```#D``````````````("_````````!P```#H`
M`````````````(B_````````!P```#L``````````````)"_````````!P``
M`#P``````````````)B_````````!P```#T``````````````*"_````````
M!P```#X``````````````*B_````````!P```#\``````````````+"_````
M````!P```$```````````````+B_````````!P```$$`````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M``!0Z,,&``#H/S0``%C#````_S7*G0``_R7,G0``#Q]``/\ERIT``&@`````
MZ>#_____)<*=``!H`0```.G0_____R6ZG0``:`(```#IP/____\ELIT``&@#
M````Z;#_____):J=``!H!````.F@_____R6BG0``:`4```#ID/____\EFIT`
M`&@&````Z8#_____)9*=``!H!P```.EP_____R6*G0``:`@```#I8/____\E
M@IT``&@)````Z5#_____)7J=``!H"@```.E`_____R5RG0``:`L```#I,/__
M__\E:IT``&@,````Z2#_____)6*=``!H#0```.D0_____R5:G0``:`X```#I
M`/____\E4IT``&@/````Z?#^____)4J=``!H$````.G@_O___R5"G0``:!$`
M``#IT/[___\E.IT``&@2````Z<#^____)3*=``!H$P```.FP_O___R4JG0``
M:!0```#IH/[___\E(IT``&@5````Z9#^____)1J=``!H%@```.F`_O___R42
MG0``:!<```#I</[___\E"IT``&@8````Z6#^____)0*=``!H&0```.E0_O__
M_R7ZG```:!H```#I0/[___\E\IP``&@;````Z3#^____)>J<``!H'````.D@
M_O___R7BG```:!T```#I$/[___\EVIP``&@>````Z0#^____)=*<``!H'P``
M`.GP_?___R7*G```:"````#IX/W___\EPIP``&@A````Z=#]____);J<``!H
M(@```.G`_?___R6RG```:",```#IL/W___\EJIP``&@D````Z:#]____):*<
M``!H)0```.F0_?___R6:G```:"8```#I@/W___\EDIP``&@G````Z7#]____
M)8J<``!H*````.E@_?___R6"G```:"D```#I4/W___\E>IP``&@J````Z4#]
M____)7*<``!H*P```.DP_?___R5JG```:"P```#I(/W___\E8IP``&@M````
MZ1#]____)5J<``!H+@```.D`_?___R52G```:"\```#I\/S___\E2IP``&@P
M````Z>#\____)4*<``!H,0```.G0_/___R4ZG```:#(```#IP/S___\E,IP`
M`&@S````Z;#\____)2J<``!H-````.F@_/___R4BG```:#4```#ID/S___\E
M&IP``&@V````Z8#\____)1*<``!H-P```.EP_/___R4*G```:#@```#I8/S_
M__\E`IP``&@Y````Z5#\____)?J;``!FD/\E`IP``&:0_R4"G```9I!32(/L
M((E\)!Q(C7PD'$B)="002(UT)!!(B50D"$B-5"0(Z&'^__](BS7RFP``2(L]
MXYL``$B)\NC;_/__@#U$G````'4UZ*W]__](B076K```2(7`=0J_`0```.@W
M_O__2(G'Z(_^__^+/2F<``#H!/___\:`T0@```"+/1><``#H\O[__XL]#)P`
M`("(J@0```+HX/[__X"(J@0```&+1"0<C7@%2+C_________'TAC_T@YQW85
M2(TUB9<``$B-/:D[```QP.C[^___2,'G`TB-'04^``#H^_W__TB+?"00,<G'
M!2JL```$````2(D%&ZP``$B+%TB)6`A(C1W=/0``2(E8&$B)$$B+%6^;``!(
MB5`0BU0D'$C_P3G*?A%,BP3/C7$$2&/V3(E$\/CKZ(U*!$4QP(/"`TB+/>>K
M``!(8\E(C36K'```2,=$R/@`````2(G!Z#S\__^)PX7`=0Y(BSV_JP``Z$K]
M__^)PTB+/;&K``#HS/S__S'`2(T].#L``.@@&```2(7`=2Y(@SV)JP```'43
M2(T]TCH``.@%&```2(D%=*L``$B+/6VK``!(A?]T!>AG+@``2(L]9*L``.C?
M_?__Z)KZ__](@\0@B=A;PT@Q[4B)YTB--7V6``!(@^3PZ`````!02(U7"$B+
M-T4QR4R-!98N``!(C0TC^O__2(T]]/W__^A'_/__2(T]<)H``$B-!6F:``!(
M.?AT#DB+!<69``!(A<!T`O_@PTB-/4Z:``!(C35'F@``N0(```!(*?Y(P?X#
M2(GP2)E(]_E(B<9(A<!T#DB+!:29``!(A<!T`O_@PX`]-9H```!U>U5(@SUZ
MF0```$B)Y4%44W0,2(L]FYD``.A>_?__2(T%CY4``$B-'9"5``!(*<-)B<1(
MP?L#2/_+2(L%_)D``$@YV',02/_`2(D%[9D``$'_%,3KY.A#____2(,]$ID`
M``!T#$B-/9%Y``#H!/W__UM!7,8%NID```%=P\-(@ST'F0```'0854B--<69
M``!(C3UF>0``2(GEZ.;\__]=Z1O___]!5S')059!54%455-(@>R8`@``9$B+
M!"4H````2(F$)(@"```QP$R+1`\XBU0/.$B-1"0(#\J)TTR)PDR)QDC!ZBA(
MP>X@2(D<2$G!Z#B!X@#_``!,"<))B?!(P>8(2<'@&('F``#_`$6)P$P)PD@)
M\DB)5$P02(/!"$B#^4!UIDB-M"0(`@``2(M0:$@S4$!(@\`(2#-0"$@S4/A(
MC0P22,'J'PG*2(E0>$@Y\'793(L72(M?$$B+=R!(BV\83(G03(G23(M/"$C!
MZAM(P>`%2`G0`T0D"(V4,)EY@EI(B=A(BW0D$$@QZ$PAR$B-M#69>8):2#'H
M1(T<`DR)RDR)R$C!Z`)(P>(>38G82`G"2(G82<'H&XG12#'(3"'02#'82`'P
M3(G>2,'F!4P)QD2--`9,B=9,B=!(P>8>2,'H`DV)]$@)\$B+="082<'L&T@Q
MPD&)P$PAVDB-M#.9>8):2#'*2`'R3(GV2,'F!4P)YD2-)!9,B=Y)P>L"2(M4
M)"!(P>8>3`G>2(V4$9EY@EI,B>%(,?!!B?-,(?!,,<!(P>D;2`'03(GB2,'B
M!4@)RDR)\4G![@)(P>$>1(TL`DB+1"0H3`GQ3(GJ2#'.28V$`)EY@EI(P>H;
M08G.3"'F3#'>2`'&3(GH2,'@!4@)T$R)XDG![`)(P>(>1(T$,$B+1"0P3`GB
M3(G&2#'128V$`YEY@EI(P>X;08G43"'I3#'Q2`'!3(G`2,'@!4@)\$2-'`A,
MB>A)P>T"2(M,)#A(P>`>3(G>3`GH28V,#IEY@EI(,<)!B<5,(<),,>)(`<I,
MB=E(P>$%2,'N&T@)\4R)QDG!Z`)(P>8>1(TT$4B+5"1`3`G&3(GQ2#'P28V4
M%)EY@EI(P>D;08GP3"'83#'H2`'03(GR2,'B!4@)RDR)V4G!ZP)(P>$>1(TD
M`DB+1"1(3`G93(GB2#'.28V$!9EY@EI(P>H;08G+3"'V3#'&2`'&3(G@2,'@
M!4@)T$R)\DG![@)(P>(>1(TL,$B+1"103`GR3(GN2#'128V$`)EY@EI(P>X;
M08G63"'A3#'92`'!3(GH2,'@!4@)\$2-!`A,B>!)P>P"2(M,)%A(P>`>3(G&
M3`G@28V,"YEY@EI(P>X;2#'"08G$3"'J3#'R2`'*3(G!2,'A!4@)\4R)[DG!
M[0)(P>8>1(T<$4B+5"1@3`GN3(G92#'P28V4%IEY@EI(P>D;08GU3"'`3#'@
M2`'03(G:2,'B!4@)RDR)P4G!Z`)(P>$>1(TT`DB+1"1H3`G!3(GR2#'.28V$
M!)EY@EI(P>H;08G(3"'>3#'N2`'&3(GP2,'@!4@)T$R)VDC!XAY)P>L"1(TD
M,$B+1"1P3`G:3(GF2#'128V$!9EY@EI(P>X;08G33"'Q3#'!2`'!3(G@2,'@
M!4@)\$2-+`A,B?!)P>X"2(M,)'A(P>`>3(GN3`GP28V,")EY@EI(P>X;2#'"
M08G&3"'B3#':2`'*3(GI2,'A!4@)\4R)YDG![`)(P>8>1(T$$4B+E"2`````
M3`GF3(G!2#'P28V4$YEY@EI(P>D;08GT3"'H3#'P2`'03(G"2,'B!4@)RDR)
MZ4G![0)(P>$>1(T<`DB+A"2(````3`GI3(G:2#'.28V$!IEY@EI(P>H;08G-
M3"'&3#'F2`'&3(G82,'@!4@)T$R)PDG!Z`)(P>(>1(TT,$B+A"20````3`G"
M3(GV2#'128V$!)EY@EI(P>X;08G03"'93#'I2`'!3(GP2,'@!4@)\$2-)`A,
MB=A)P>L"2(N,))@```!(P>`>3(GF3`G828V,#9EY@EI(P>X;2#'"08G#3"'R
M3#'"2`'13(GB2,'B!4@)\DR)]DG![@)(P>8>B=),"?9(`<I(BXPDH````$@Q
M\$&)U4PAX$F-C`B9>8):38GH3#'82<'H&T@!P4R)Z$C!X`5,"<!-B>!)P>P"
M2<'@'HG`30G@28GT2`'(B?9-,<2)P4@#M"2P````1#'B3(ND)*@```!/C9PC
MH>O9;DF)S$P!VDF)RTG![!M)P>,%30GC18G;3`':38GK2<'M`DG!XQY!B=1-
M">M-B<5%B<!,`X0DN````$TQW40QZ$V)Y4B-M`:AZ]EN3(G@2<'M&TC!X`5,
M">B)P$@!\$B)SDC!Z0)(P>8>08G%2`G.3(G918G;2#'Q,<I,`YPDP````$F-
MC!"AZ]EN3(GJ38GH2<'H&TC!X@5,"<*)TDR-!!%,B>%)P>P"2,'A'D2)PDP)
MX4F)](GV2`.T),@```!),<Q$,>!)B=1-C9P#H>O9;DB)T$G![!M(P>`%3`G@
MB<!-C20#3(GH2<'M`DC!X!Y%B>-,">A)B<V)R4@#C"30````23'%13'H38G=
M3HV$!J'KV6Y,B=Y)P>T;2,'F!4P)[HGV3`'&28G02,'J`DG!X!Y!B?5)"=!(
MB<*)P$PQPD$QU$R)ZDZ-I"&AZ]EN3(GI2,'B!4C!Z1M("<J)TDF-#!1,B=I(
MP>(>2<'K`D&)S$@#A"38````3`G:38G#18G`3`.$).````!),=-$,=Y-B>-(
MC;0PH>O9;DR)X$G!ZQM(P>`%3`G8B<!(`?!,B>Y)P>T"2,'F'D&)PTP)[DF)
MU8G22`.4).@```!),?5$,>E-C:P(H>O9;DR)V4V)V$G!Z!M(P>$%3`G!B<E-
MC40-`$R)X4G![`)(P>$>18G%3`GA28GTB?9(`[0D\````$DQS$0QX$R-I`*A
MZ]EN3(GH3(GJ2,'J&TC!X`5("=")P$F-%`1,B=A)P>L"2,'@'D&)U$P)V$F)
MRXG)23'#2`.,)/@```!%,=A-B>-.C80&H>O9;DR)YDG!ZQM(P>8%3`G>B?9,
M`<9-B>A)P>T"2<'@'D&)\TT)Z$F)Q8G`2`.$)``!``!-,<5$,>I,C:P1H>O9
M;DR)VDR)V4C!Z1M(P>(%2`G*B=))C4P5`$R)XDG![`)(P>(>08G-3`GB38G$
M18G`3`.$)`@!``!),=1$,>9-B>Q(C;0PH>O9;DR)Z$G![!M(P>`%3`G@B<!(
M`?!,B=Y)P>L"2,'F'D&)Q$P)WDF)TXG223'S1#'938V<"*'KV6Y,B>%-B>!(
MP>$%2<'H&T@#E"00`0``3`G!B<E-C00+3(GI2<'M`DC!X1Y%B<-,">E)B?6)
M]D@#M"08`0``23'-1#'H3(VL`J'KV6Y,B=A,B=I(P>H;2,'@!4@)T(G`28U4
M!0!,B>!)P>P"2,'@'D&)U4P)X$F)S(G)2`.,)"`!``!),<1%,>!-B>Q.C80&
MH>O9;DR)[DG![!M(P>8%3`GFB?9,`<9-B=A)P>L"2<'@'D&)]$T)V$F)PXG`
M33'#1#':3(V<$:'KV6Y,B>),B>%(P>D;2,'B!4@)RHG228T,$TR)ZDG![0)(
MP>(>08G+3`GJ38G%2`.$)"@!``!%B<!),=5,`X0D,`$``$0Q[DV)W4B-M#"A
MZ]EN3(G82<'M&TC!X`5,">B)P$@!\$R)YDG![`)(P>8>08G%3`GF28G4B=)(
M`Y0D.`$``$DQ]$0QX4V-I`BAZ]EN3(GI38GH2<'H&TC!X05,"<&)R4V-!`Q,
MB=E)P>L"2,'A'D6)Q$P)V4F)\XGV2`.T)$`!``!),<M$,=A-B>-(C90"H>O9
M;DR)X$G!ZQM(P>`%3`G81(T<$$R)Z$G![0)(P>`>3`GH28G-B<E),<6)PD4Q
MZ$V)W4Z-A`:AZ]EN3(G>2,'F!4G![1M,">Y,BZPD2`$``$:--`9-B>!)P>P"
M2<'@'DT)X$P)P$2)QDF)Q$B)T$@A\$TAW$D)Q+C<O!N/20'%3`'I38GU20',
M3(GQ2<'M&TC!X05,">E&C2PA3(G92<'K`DF)]$C!X1Y,"=E!B<M)"<A-(=Q-
M(?!-">!,BZ0D4`$``$D!Q$P!XDV)[$D!T$R)ZDG![!M(P>(%3`GB1HTD`DR)
M\DG![@)(P>(>3`GR38G>2`G108G032'&3"'I3`GQ3(NT)%@!``!)`<9,`?9-
MB>9(`?%,B>9)P>X;2,'F!4P)]D2--`Y,B>Y)P>T"2,'F'DP)[DV)Q8GQ2`GR
M22'-3"'B3`GJ3(NL)&`!``!)`<5-`>M-B?5,`=I-B?-)P>T;2<'C!4T)ZT6-
M+!--B>-)P>P"2<'C'DT)XTF)S$2)VDP)WDDAU$PA]DP)YDR+I"1H`0``20'$
M30'@38GL3`'&38GH2<'L&TG!X`5-">!%C20P38GP2<'N`DG!X!Y-"?!)B=9$
MB<9-"<-)(?9-(>M-"?-,B[0D<`$``$D!QDP!\4V)YDD!RTR)X4G![AM(P>$%
M3`GQ1HTT&4R)Z4G![0)(P>$>3`GI28GU08G+20G(32'=32'@30GH3(NL)'@!
M``!)`<5,`>I-B?5)`=!,B?))P>T;2,'B!4P)ZD:-+`),B>))P>P"2,'B'DP)
MXDV)W$&)T$@)T4PA\4TAQ$P)X4R+I"2``0``20'$3`'F38GL2`'Q3(GN2<'L
M&TC!Y@5,">9$C20.3(GV2<'N`DC!YAY,"?9-B<:)\4@)\DDASDPAZDP)\DR+
MM"2(`0``20'&30'S38GF3`':38GC2<'N&TG!XP5-"?-%C30338GK2<'M`DG!
MXQY-">M)B<U$B=I,"=Y)(=5,(>9,">Y,BZPDD`$``$D!Q4T!Z$V)]4P!QDV)
M\$G![1M)P>`%30GH18TL,$V)X$G![`))P>`>30G@28G41(G&30G#22'T32'S
M30GC3(ND))@!``!)`<1,`>%-B>Q)`<M,B>E)P>P;2,'A!4P)X4:-)!E,B?%)
MP>X"2,'A'DP)\4F)]D&)RTD)R$TAWDTAZ$T)\$R+M"2@`0``20'&3`'R38GF
M20'03(GB2<'N&TC!X@5,"?)&C30"3(GJ2,'B'DG![0),">I-B=U!B=!("=%-
M(<5,(>%,">E,BZPDJ`$``$D!Q4P![DV)]4@!\4R)]DG![1M(P>8%3`GN1(TL
M#DR)YDG![`)(P>8>3`GF38G$B?%("?))(<Q,(?),">),BZ0DL`$``$D!Q$T!
MXTV)[$P!VDV)ZTG![!M)P>,%30GC38GT2<'N`DG!Y!Y!`=--"?1)B<Y$B>),
M">9)(=9,(>Y,"?9,B[0DN`$``$D!QDT!\$V)WDP!QDV)V$G![AM)P>`%30GP
M18TT,$V)Z$G![0))P>`>30GH28G51(G&30G$22'U32'<30GL3(NL),`!``!)
M`<5,`>E-B?5)`<Q,B?%)P>T;2,'A!4P)Z4$!S$R)V4G!ZP)(P>$>3`G928GS
M08G/20G(32'[32'P30G83(N<),@!``!)`<-,`=I-B>-)`=!,B>)(P>(%2<'K
M&TP)VDV)\TG![@))P>,>1HTL`DR)^DT)\T6)WDP)V4PA\DPAX4@)T4B+E"30
M`0``2`'"2`'63(GJ2`'Q3(GN2,'B!4C![AM("?),B>9)P>P"2,'F'D2-!`I,
MB?),">9,B<%!B?1)"?-(P>D;3"'B32'K20G32(N4)-@!``!(`<),`?I)`=-,
MB<)(P>(%2`G*3(GI2<'M`DC!X1Z)TDP)Z4P!VDV)Y4@)SD&)ST@#A"3@`0``
M08G332']3"'&3`GN28G%3(G830'U2,'H&TD!]4R)WDC!Y@5("<9,B<!)P>@"
M2,'@'HGV20G`N-;!8LI,`>Y,,<%!B?5-B<9%B<`QRDB+C"3H`0``2`'!20',
M2HT,(DR)ZDV)[$G![!M(P>(%3`GBB=)(`<I,B=E)P>L"2,'A'D&)U$D)RTB+
MC"3P`0``33'>2`'!1#'V20'/3(GA20'W3(GF2,'A!4C![AM("?&)R4F--`],
MB>E)P>T"2,'A'D&)]DD)S4B+C"3X`0``2`'!3HT\`4V)V$R)\46)VTTQZ$C!
MZ1M$,<)-B?!)P>`%3`'Z20G(3(GA2<'L`D6)P$C!X1Y)`=!(BY0D``(``$P)
MX46)QT@!PDP!VDV)ZT6)[4DQRT0QWDV)^T@!UDR)^DG!XP5(P>H;20G33(GR
M2<'N`DC!XAY%B=M)"=9(BY0D"`(``$D!\TB+M"00`@``18G<2`'"20'52(G*
MB<E,,?)!,=!,B>)-`>A-B>5)P>4%2,'J&T@!QDD)U4R)^DG![P)(`?%(P>(>
M18GM3(GV18GV3`GZ30'H2#'618G%03'S3(GN20'+3(GI2,'N&TC!X05("?%,
MB>Y)P>T"B<E(P>8>20'+3(GA2<'L`DP)[DC!X1Y%B=])"<Q(BXPD&`(``$@!
MP4D!SDB)T8G23#'A03'(3(GY30'P38G^2,'I&TG!Y@5)"<Y(BXPD(`(``$6)
M]D@!P4T!\$@!RDR)X46)QD6)Y$@Q\4$QRTR)\4D!TTR)\DC!Z1M(P>(%2`G*
M3(GQ2<'N`HG22,'A'DD!TTR)^DG![P),"?%(P>(>18G=20G72(N4)"@"``!(
M`<))`=1(B?*)]DPQ^D$QT$R)ZDT!X$V)[$C!ZAM)P>0%20G42(N4)#`"``!%
MB>1(`<)-`>!(`=9,B?I%B<1%B?](,<I!,=-,B>))`?-,B>9(P>H;2,'F!4@)
MUDR)ZHGV20'S2,'B'DB+M"1``@``2<'M`D6)WDD)U4B+E"0X`@``2`'&2`'"
M20'72(G*B<E,,>I(`?%,B>Y%B>U!,=!,B?)-`?A-B?=(P>H;2<'G!4D)UTR)
MXDG![`)(P>(>18G_3`GB30'X2#'618G'03'S3(G^20'+3(GY2,'N&TC!X05(
M"?%,B?Z)R4D!RTR)\4G![@)(P>$>18G<20G.2(N,)$@"``!(`<%)`<U(B=&)
MTDPQ\4$QR$R)X4T!Z$V)Y4G!Y05(P>D;2<'O`DD)S4B+C"10`@``2,'F'DP)
M_D6)[4@!P4T!Z$@!RDR)\46)Q46)]D@Q\4$QRTR)Z4D!TTR)ZDC!Z1M(P>(%
M2`G*3(GI2<'M`HG22,'A'DD!TTR)XDG![`),">E(P>(>18G?20G42(N4)%@"
M``!(`<))`=9(B?*)]DPQXD$QT$R)^DT!\$V)_DC!ZAM)P>8%20G62(N4)&`"
M``!%B?9(`<)-`?!(`=9,B>)%B<9%B>1(,<I!,=-,B?))`?-,B?9(P>H;2,'F
M!4@)UDR)^DG![P)(P>(>B?9)"==(BY0D:`(``$D!\T6)W4@!PDD!U$B)RHG)
M3#'Z03'03(GJ30'@38GL2,'J&TG!Y`5)"=1,B?))P>X"2,'B'D6)Y$D)UDB+
ME"1P`@``30'@1(G&38GT2`'"2`'13(GZ18G_3#'R18GV03'32(GR20'+2(GQ
M2,'J&TC!X05("=&)R4P!V4V)ZTG!XQY)P>T"B<I-"=U,BYPD>`(``$TQ[$D!
MPT4QX$@#A"2``@``30'?28G330''28G02<'K&TG!X`5-"=A)B?-(P>X"2<'C
M'D4!^$P)WDF)TTC!Z@)%`<%)P>,>3(E/"$D)TTJ-%#!,B>A$`V\@2#'P1`';
M`>Y,B6\@,<%(B5\02(T$"DR)PDR)P4B)=QA(P>(%2,'I&T@)R@'000'"3(D7
M2(N$)(@"``!D2#,$)2@```!T!>BVYO__2('$F`(``%M=05Q!74%>05_#05=!
M5D%50515,>U344B%_W1E3(LU4X,``$B)^DV%]G16B@*$P'0)/#UT!4C_PNOQ
M*?I)B?=)B?U-B?1(8]I)BRPD2(7M=#!(B=I,B>Y(B>_H#^3__X7`=1B`?!T`
M/74132GT2(UL'0%)P?P#18DGZP9)@\0(Z\=:2(GH6UU!7$%=05Y!7\-(@^P8
M9$B+!"4H````2(E$)`@QP$B-="0$Z%S___](BU0D"&1(,Q0E*````'0%Z.OE
M__](@\08PU532(G[2(/L&&1(BP0E*````$B)1"0(,<!(C6PD!#'`2(GN2(G?
MZ!?___](A<!T(DAC5"0$2(L%<H(``$B-!-!(BU`(2(D02(72=-)(@\`(Z^Y(
MBT0D"&1(,P0E*````'0%Z'_E__](@\086UW#059!54%454B)_5-(B?-(@^P0
M9$B+!"4H````2(E$)`@QP(`^/74#2/_#28/._T4Q[4B-="0$2(G?1(GH3(GQ
M\JY(B>](]]%.C20QZ(3^__](B<)(A<!T,TB)QTR)\42)Z/*N28G-2??530'U
M33GE#X*E````,<"*#`.(#`)(_\"$R77S,<#I#P$``$R+-:Z!```QP$&)Q4C_
MP$F#?,;X`'7R08UU`DAC]DC!Y@.#/022````=!Q,B??H:N'__TB)!7N!``!(
MA<!U.(/(_^G(````QP7<D0```0```$B)]^@TXO__2(7`=.%)8]5,B?9(B<=(
MP>(#Z"WB__](B04^@0``2(L%-X$``$ECU4C'1-`(`````$2);"0$2(GHBA"$
MTG0*@/H]=`5(_\#K\$@IZ$AC3"0$2(L5!($``$B828U\!`),C2S*Z,SA__])
MB44`2(7`#X1Q____2&-4)`1(BP7;@```2(L$T$C_Q8I5_TB-2`&($(#Z/70)
MA-)T!4B)R.OFQ@`],<"*%`.(%`%(_\"$TG7SZ>K^__](BUPD"&1(,QPE*```
M`'0%Z,GC__](@\006UU!7$%=05[#059!54%455-(@>R@````9$B+!"4H````
M2(F$))@````QP$B%_P^$[````(`_`$B)_0^$X````.@`X/__28/-_TF)Q$B%
MP`^$RP```$R)Y^BHX/__2(7`#X2J````2(U8$TB--;4?``!(B=_H?.#__X7`
M=-A(C36A'P``2(G?Z&G@__^%P'3%,<!(B>],B>GRKDB)WTB)RDR)Z?*N2/?2
M2(G(2/?0C3P02&/_Z*S@__](B=E(B>I(C35B'P``28G&2(G',<#HLN+__TR)
M]TB-="0(Z&7B__],B??_P'07BT0D("4`\```/0!```!U!^@-____ZP7H4N#_
M_TR)]^@JXO__Z47___],B>?HG>#__TB)[^CEX?__2(N$))@```!D2#,$)2@`
M``!T!>B-XO__2('$H````%M=05Q!74%>PU-(B?M(@>R@````9$B+!"4H````
M2(F$))@````QP$B-="0(Z#7@__^%P'4QBU0D(('B`/```('Z`$```'0(@?H`
MH```=1F^`@```$B)W^CZWO__A<`/E,`/ML#K`C'`2(N,))@```!D2#,,)2@`
M``!T!>@&XO__2('$H````%O#4(L]QGX``.BAX?__2(L5,GX``$%82(T-65T`
M`$B--4,>``!(B<?I8N'__U"+/9M^``#H=N'__TB)Q^C!____BSV(?@``Z&/A
M__],C07`(```13')05I,B<%(C16M#@``2(TU&QX``$B)Q^E^WO__05154TB!
M[!`@``!D2(L$)2@```!(B80D""```#'`2(UL)`;HAM[__TR-!?D=``"^`1``
M`$B)[XG!2(T5[!T``#'`Z"?>__^#^/]U!S')Z8$```!(8]!(@?H`$```=@(/
M"X7`>.=(C9PD!Q```+H`$```2(GO2(G>Z+'?__])B<2%P'C(C7@!2&/_Z)_>
M__](B<%(A<!TM4EC[$@YV',)2(T$*$@YPW*W2#G9=@E(C00K2#G!<JE!@?P!
M$```?Z!(B<](B>I(B=[HD>#__\8$*`!(B<%(B[0D""```&1(,S0E*````$B)
MR'0%Z)_@__](@<00(```6UU!7,/I`/___T%7059!54%454B)_4B-/24=``!3
M2(GS2('LJ!```&1(BP0E*````$B)A"28$```,<#H.OK__[XO````2(GO28G%
MZ)C>__](A<!T%DB)[DB-/>P<```QP.BZ^O__Z28!```QP$B)[TB-->$<``!(
M@\G_\JY(B=],C3UR'```2(G*2/?21(UR_^BBW___2(G#2(7;=+>`.P!U`TR)
M^TV%[7032(G>3(GOZ!+=__^%P`^$O0```#'`2(/)_TB)W_*N2(G*2/?2C4+_
M2&/0@'P3_R]U"__(2&/0Q@03`.OK0HU$,`$]_P\```^/7O___TR-I"28````
M28GI2(G9,<!,C05,'```2(T5-!T``+X`$```3(GGZ%;<____P#T`$```=@(/
M"TB-="0(3(GGZ-[>__^%P'4]BT0D("4`\```/0"```!U+;X!````3(GGZ`W<
M__^%P'4<3(GF2(T]XAL``.BR^?__3(GGZ"+=__](B<7K%DB--=8;```Q_^BO
MWO__2(G#Z0C___](BY0DF!```&1(,Q0E*````$B)Z'0%Z.S>__](@<2H$```
M6UU!7$%=05Y!7\-(B?B*%X32=`Q(_\>`^B](#T3'Z^[#2(7_=$N`/P!(B?YT
M0TB#R?\QP/*N2/?12(U4#OY(.=9S'8`Z+W4-2/_*Z_%(B<)(.<9S"X`Z+TB-
M0O]U[^LB2#G6=1V`/B](C3TX&P``=0=(C3W.&@``Z6C<__^`.B]U"$C_RD@Y
MUG+S2"GR2(U"`D@]`!```'<D2/_"2('Z`!```'8"#PM02(T]=GL``.CAW/__
M2(T%:GL``%K#,<##4TB--6U9``"Y(@```$B#[#!D2(L$)2@```!(B40D*#'`
M2(U\)`9(C5PD!O.D2(T]M1H``.@&^/__,<!(C3VP&@``Z/CW__\QP$B-/:H:
M``#HZO?__S'`2(T]I1H``.C<]___,<!(C3V>&@``Z,[W__\QP$B-/:`:``#H
MP/?__S'`2(T]1QH``.BR]___,<!(C3V0&@``Z*3W__\QP$B-/8P:``#HEO?_
M_S'`2(T]B!H``.B(]___,<!(C3T8&@``Z'KW__\QP$B-/78:``#H-/?__TB%
MP'012(G&2(T]3AH``#'`Z,3W__\QP$B-/6,:``#H$/?__TB%P'012(G&2(T]
M81H``#'`Z*#W__](C3U>&@``,<#H[/;__TB-/:T9``!(B<9(A<!U'3'`2(T]
M3QH``.C/]O__2(7`=`Y(B<9(C3W?&0``,<#K)$B->Q&Z"@```$B--3@:``#H
MA=K__X7`=1!(C7,;2(T]MQD``.@Y]___,<!(C34A&@``2(T]AAD``.@D]___
M2(M$)"AD2#,$)2@```!T!>B'W/__2(/$,%O#@STJ>0``_W4T44B-/7$9```Q
MP.A+]O__,=)(A<!T$(H`/#`/E<$QTH3`#Y7"(<J)%?QX``"+!?9X``!:PXL%
M[G@``,-1Z$?<__^)Q^B@VO__,=)(A<!T`TB+$$B)T%K#050QP%5(B?U(C3V-
M&0``4^CN]?__2(GN2(7`=&*`.`!(B<-T6DB)Q^@4VO__2(7`=5](@\[_2(GO
M2(GQ\JY(B=](B<I(B?'RKDCWTDB)R$CWT$B-/`+H9MG__TB--7`9``!)B=A(
MB>I)B<1(B<=(C0UL&```,<#H9=O__TR)YEM(C3T5&0``73'`05SI&/;__UM=
M05S#05=(C34">```28G_N0P```!!5D%505154TB![&B!``!D2(L$)2@```!(
MB80D6($``#'`2(T%XQ@``$B-?"182,=$)#@`````\Z5(B40D*$B-!987``!(
MC3W8%P``2(E$)#!(C06Y&```2(E$)$!(C06R&```2(E$)$@QP$C'1"10````
M`.CC]/__2(7`=""`.`!(B<-T&$B)Q^C+_O__2(G?Z.38__](B</IOP<``#'`
M2(UL)$#HD_[__TB)PTB%P'4Y2(M]`$B%_W0I,<#HFO3__TB%P'4&2(/%".OE
M@#@`=/5(B<?HH-C__TB)PTB%P'3EZP=(C1T:&```,<!(B=](C2TH&```2(/)
M__*N2(G*2/?22(U\$O_H#=C__TF)Q4F)Q`^V$X32=!9,B>=(B>XQP$C_P^@0
MVO__28/$`NOC2(UL)%A(BUT`2(7;=#9(B=\QP.@4]/__2(G#2(7`=!Z`.`!T
M&4B)Q^B@]___A<!T#4B)W^@1V/__2(G#ZP9(@\4(Z\%,C60D*$B%VW4L28LL
M)$B%[70C@'T``'0=2(GOZ&CW__^%P'0+2(GOZ-G7__](B<-)@\0(Z\](@\[_
M,<!(B=](B?'RKDR)[TB)RDB)\?*N2/?22(G(2/?0C:P0`@0``$AC[4B)[^@\
MU___38GI3(T%/!<``$B-#4T6``!(B<=)B<1(B=HQP$B--2@7``#H--G__[[`
M`0``3(GGZ,?8____P'4OZ*[8__^#.!%T)>BDV/__28L73(GA2(L]MW$``$2+
M`$B--?46```QP.@6V/__ZS9,C;0DB````$R)YTR)]N@!U___B40D"(7`="))
MBQ=(BSU_<0``3(GA,<!(C37V%@``Z-[7__\QV^G:!0``BX0DH````"4`\```
M/0!```!URXN<)*0```#HZ-C__SG#=;N+A"2@````)?\!```]P`$``'6H2(GO
MZ%G6__](C3TX%@``2(G#,<#HBO+__TB%P'4%38LOZQM(B<?HEM;__TF+/TB)
MQNC]]___28G%2(7`=.!(@\G_,<!,B>_RKDB)SDCWUDB-;O^#_0-^9DACQ4B-
M-:46``!)C7P%_.B%U?__A<!U3H/]!'0.@^T$2&/M08!\+?\O=3M)BV\(2(7M
M=#(QP$B#R?](B>_RKDB)RDCWTDB-0O](@_@#=A=(C7P5^TB--5D6``#H.=7_
M_X7`3`]$[3'`Z'O[__^%P`^%(P0``#'V3(GOZ/K5__]!B<>%P`^$#@0``+H"
M````2,?&[O___XG'Z-S4__](C:PD6`$``+H&````1(G_2(GNZ-36__^`O"18
M`0```'5E@+PD60$``$-U6X"\)%H!``!!=5&`O"1;`0``0W5'@+PD7`$``$AU
M/8"\)%T!``!%=3.Z`@```$C'QL;___]$B?_H=-3__[HI````2(GN1(G_Z'36
M__],C0UA%@``28GHZ50#```QTC'V38UN.$2)_^A%U/__N(FKS>](QX0DB```
M``$C16=(B80DD````$@MB\X25TB)A"28````2`7R!!@K2,>$)*````!V5#(0
M2(F$)*@```!(QX0DL`````````!(QX0DN`````````#'A"0``0```````+H`
M@```2(GN1(G_Z.'5__])B<&)1"0(A<`/CH8!``!(BXPDL````$ECP8T4P4@Y
MT78(2/^$)+@```!(8[PD``$``$C!Z!U(B90DL````$@!A"2X````A?\/A*0`
M``!!N$````!!*?A%.<%%#T[!3`'O26/(2#GO<PE(C00/2#G%<@](.>]V#$B-
M1`T`2#G'<P(/"TR)3"081(E$)!!(@?D`@```=^M(B<I(B>Y(B4PD".CKU?__
M1(M$)!!(BTPD"(N$)``!``!,BTPD&$0!P(/X0(F$)``!```/A2'___]$B<A(
MC70-`$R)]T0IP$B)="00B40D".@FV?__2(MT)!#K`TB)[H-\)`@_?DU).?5S
M#4F-1GA(.?`/AW/___],.>Y(C4Y`<PE).<T/@F'___^Z0````$R)[TB)3"00
MZ%_5__],B?>#;"0(0.C2V/__2(M,)!!(B<[KK$AC5"0(3#GN=@Y)C405`$@Y
MQ@^"(/___TPY[G,-2(T$%DDYQ0^"#O___TB#^D@/AP3___],B>_H#-7__XM$
M)`B)A"0``0``Z5O^__]$B?_H)-3__TB+A"2P````BZPDL````$2+K"2X````
M2,'H`P_-@^`_00_-C4@!2)B#^3C&A`3`````@$AC^7XLND````!-C7XX,?8I
MRDP!_TACTNA$TO__3(GWZ!S8__^Z.````#'V3(G_ZQ&Z.````$F-?#XX,?8I
MRDACTN@:TO__3(GW1(FL)/@```!,C:PD+P$``(FL)/P```!,C;0D&P$``#'M
MZ-'7__^+A"2(````38GH#\B)A"0;`0``BX0DD`````_(B80D'P$``(N$))@`
M```/R(F$)",!``"+A"2@````#\B)A"0G`0``BX0DJ`````_(B80D*P$``$(/
MME0U`$R)[S'`2/_%2(TUOA$``$R)1"0(28/%`NC+T___2(/]%$R+1"0(==+&
MA"17`0```$R-#043``!(C0VL$```3(GB2(G?,<!(C34K$@``Z);3___IDP``
M`$B--4,1``!(C3W$$```,<#H1.[__TB-+<D2``#HT-#__TR-#;T2``!,B>)(
MC0UA$```08G`2(TU]!$``$B)WS'`Z$O3__^^P`$``$B)W^C>TO___\!U/.C%
MTO__@S@1=3+_1"0(Z(?0__](C0TB$```3(GB2(G?08G`4$B--;P1```QP%5$
MBTPD&.@"T___6EGKLTR)Y^BFTO__2(T]V0\``$B)WC'`Z*WM__](B=_H_/;_
M_TB)V$B+G"18@0``9$@S'"4H````=`7H`M/__TB!Q&B!``!;74%<05U!7D%?
MPT%505154U*+/;-O``#HCM+__XL]J&\``$B)P^B`TO__BI.X````2(T]J`\`
M`(B0N0```#'`Z)CL__](A<!T"X`X,74&@'@!`'0',<#H>O3__XL]:6\``.A$
MTO__N0L```"Z`0```$B--0T1``!(B<?HN]#__TB%P'4UBSU`;P``Z!O2__^Y
M`P```+H!````2(TUZ1```$B)Q^B2T/__2(G#2(7`#X7.````Z1`!``!(BT`0
MNP$```!,BV`H.1U^?P``1(UK_XL]]&X``'X:Z,W1__\QR4ECU4R)YDB)Q^AM
MS___2(7`=12+!5)_``#_R$0YZ'6%NP$```#K5DB+*(M%#"4`!"``/0`$``!U
M!DB+11#K'8L]IFX``.B!T?__N0(````QTDB)[DB)Q^BOT?__2(L-`'\``$AC
MTTB)QDB+/-'HV<[__X7`=9W_P^EJ____.1WH?@``BSUB;@``#XX6____Z#?1
M__],B>;_PTB)Q^@*SO__Z]I(BT`0BST^;@``2(LHZ!;1__](C17P#P``2(G'
M2(GNZ+3/__](BT,02(L8]D,.0'06BST1;@``Z.S0__](B=Y(B<?HL<[__XL]
M^VT``.C6T/__N0,```"Z`0```$B--:L/``!(B<?H3<___TB)Q4B%P`^$AP``
M`$B-/:T-```QP.C5ZO__2(G#2(7`=!I(BT40BSVQ;0``2(LHZ(G0__](B=I(
MB>[K3^@^[___BSV6;0``2(7`2(G#2(M%$'0@2(LHZ&+0__](B=I(B<=(B>[H
M!,___TB)W^@,T/__ZR!(BQ7;?0``2(L82(LJZ#C0__](B=Y(B>I(B<?HVL[_
M_XL]1&T``.@?T/__N@$```!(C37[#@``2(G'Z!O-__^+/25M``!(B</H_<__
M_TB-%?,.``!(B=Y(B<?HF\[__XL]!6T``.C@S___2(T]TPP``,:`N0`````Q
MP.C]Z?__2(D%;'T``$B%P'4D2(L]4'T``.AX]/__2(D%5'T``$B%P'4,2(T]
MHPX``.CKS/__2(L]/'T``+[``0``Z#K/__^-4`&#^@%V)H/X$70AB<%(BP4,
M?0``2(L5%7T``$B-/8H.``!(BS`QP.BLS/__6%M=05Q!7<-54TB)^U'HU?#_
M_TB)Q^BW\/__2(G%,<#H!O/__X7`="E(A=MT)(`[`'0?2(TU'`T``$B)[^B*
MS?__2#GH=0M:2(G?6UWIGNO__UA;7<-52(GE4TB-'9IG``!22(L#2(/X_W0(
M_]!(@^L(Z^]86UW#4.C2T?__6,,`````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````+BX`)7,O)7,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN
M=&5R;F%L<SHZ4$%2.CI"3T]4`&5X90`O<')O8R\E:2\E<P!005)?5$5-4`!0
M05)?4%)/1TY!344`.@`O`%!%4DPU3$E"`%!%4DQ,24(`4$523#5/4%0`4$52
M3$E/`%!!4E])3DE424%,25I%1`!005)?4U!!5TY%1`!005)?0TQ%04X`4$%2
M7T1%0E5'`%!!4E]#04-(10!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"04Q?
M5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"04Q?
M0TQ%04X`4$%27T-,14%./0`Q`$Q$7TQ)0E)!4EE?4$%42`!365-414T`+W1M
M<`!54T52`%5315).04U%`"4P,G@`<&%R+0`E<R5S)7,E<P`E<SH@8W)E871I
M;VX@;V8@<')I=F%T92!S=6)D:7)E8W1O<GD@)7,@9F%I;&5D("AE<G)N;STE
M:2D*`"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I<R!U;G-A9F4@*'!L
M96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E<F%T:6]N*0H`<&%R
M;``N<&%R`"5S)7-C86-H92TE<R5S`"5S)7-T96UP+25U)7,`)7,E<W1E;7`M
M)74M)74E<P!414U01$E2`%1-4`!!4D=6`!@`<&5R;``P`%!!4CHZ4&%C:V5R
M.CI615)324].`#$N,#0W`%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T
M;W)Y`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E(&-A8VAE('-U8F1I<F5C=&]R
M>2`E<R!F86EL960@*&5R<FYO/25I*0H`+64`+2T`979A;"`G97AE8R`O=7-R
M+V)I;B]P97)L("`M4R`D,"`D>S$K(B1`(GTG"FEF(#`[(",@;F]T(')U;FYI
M;F<@=6YD97(@<V]M92!S:&5L;`IP86-K86=E(%]?<&%R7W!L.PIM>2`H)'!A
M<E]T96UP+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[
M4$%27T-,14%.?2D@>PIR97%U:7)E($9I;&4Z.E1E;7`["G)E<75I<F4@1FEL
M93HZ0F%S96YA;64["G)E<75I<F4@1FEL93HZ4W!E8SL*;7D@)'1O<&1I<B`]
M($9I;&4Z.D)A<V5N86UE.CID:7)N86UE*"1P87)?=&5M<"D["F]U=',H<7%[
M4F5M;W9I;F<@9FEL97,@:6X@(B1P87)?=&5M<")]*3L*1FEL93HZ1FEN9#HZ
M9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M9&ER(#H@=6YL:6YK('TL("1P
M87)?=&5M<"D["G)M9&ER("1P87)?=&5M<#L*:68@*"UD("1P87)?=&5M<"`F
M)B`D7D\@;F4@)TU35VEN,S(G*2!["FUY("1T;7`@/2!N97<@1FEL93HZ5&5M
M<"@*5$5-4$Q!5$4@/3X@)W1M<%A86%A8)RP*1$E2(#T^($9I;&4Z.D)A<V5N
M86UE.CID:7)N86UE*"1T;W!D:7(I+`I3549&25@@/3X@)RYC;60G+`I53DQ)
M3DL@/3X@,"P**3L*<')I;G0@)'1M<"`B(R$O8FEN+W-H"G@],3L@=VAI;&4@
M6R!<)'@@+6QT(#$P(%T[(&1O"G)M("UR9B`G)'!A<E]T96UP)PII9B!;(%PA
M("UD("<D<&%R7W1E;7`G(%T[('1H96X*8G)E86L*9FD*<VQE97`@,0IX/6!E
M>'!R(%PD>"`K(#%@"F1O;F4*<FT@)R(@+B`D=&UP+3YF:6QE;F%M92`N("(G
M"B(["F-H;6]D(#`W,#`L)'1M<"T^9FEL96YA;64["FUY("1C;60@/2`D=&UP
M+3YF:6QE;F%M92`N("<@/B]D978O;G5L;"`R/B8Q("8G.PIC;&]S92`D=&UP
M.PIS>7-T96TH)&-M9"D["F]U=',H<7$H4W!A=VYE9"!B86-K9W)O=6YD('!R
M;V-E<W,@=&\@<&5R9F]R;2!C;&5A;G5P.B`I"BX@)'1M<"T^9FEL96YA;64I
M.PI]"GT@?0I"14=)3B!["DEN=&5R;F%L<SHZ4$%2.CI"3T]4*"D@:68@9&5F
M:6YE9"`F26YT97)N86QS.CI005(Z.D)/3U0["F5V86P@>PI?<&%R7VEN:71?
M96YV*"D["FUY("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["FUY("5#;VYF
M:6<@/2`H"G!A=&A?<V5P("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@
M.B`G.B<I+`I?97AE("`@("`@("`]/B`H)%Y/(#U^("]>*#\Z35-7:6Y\3U,R
M?&-Y9W=I;BDO(#\@)RYE>&4G(#H@)R<I+`I?9&5L:6T@("`@("`]/B`H)%Y/
M(#U^("]>35-7:6Y\3U,R+R`_("=<7"<@.B`G+R<I+`HI.PI?<V5T7W!R;V=N
M86UE*"D["E]S971?<&%R7W1E;7`H*3L*;7D@*"1S=&%R=%]P;W,L("1D871A
M7W!O<RD["GL*;&]C86P@)%-)1WM?7U=!4DY?7WT@/2!S=6(@>WT["F]P96X@
M7T9(+"`G/"<L("1P<F]G;F%M92!O<B!L87-T.PIB:6YM;V1E*%]&2"D["FUY
M("1B=68["FUY("1S:7IE(#T@+7,@)'!R;V=N86UE.PIM>2`D;V9F<V5T(#T@
M-3$R.PIM>2`D:61X(#T@+3$["G=H:6QE("@Q*0I["B1O9F9S970@/2`D<VEZ
M92!I9B`D;V9F<V5T(#X@)'-I>F4["G-E96L@7T9(+"`M)&]F9G-E="P@,B!O
M<B!D:64@<7%;<V5E:R!F86EL960@;VX@(B1P<F]G;F%M92(Z("0A73L*;7D@
M)&YR96%D(#T@<F5A9"!?1D@L("1B=68L("1O9F9S970["F1I92!Q<5MR96%D
M(&9A:6QE9"!O;B`B)'!R;V=N86UE(CH@)"%=('5N;&5S<R`D;G)E860@/3T@
M)&]F9G-E=#L*)&ED>"`](')I;F1E>"@D8G5F+"`B7&Y005(N<&U<;B(I.PIL
M87-T(&EF("1I9'@@/CT@,"!\?"`D;V9F<V5T(#T]("1S:7IE('Q\("1O9F9S
M970@/B`Q,C@@*B`Q,#(T.PHD;V9F<V5T("H](#(["GT*;&%S="!U;FQE<W,@
M)&ED>"`^/2`P.PHD;V9F<V5T("T]("1I9'@@+2`T.PIS965K(%]&2"P@+21O
M9F9S970L(#(["G)E860@7T9(+"`D8G5F+"`T.PIS965K(%]&2"P@+21O9F9S
M970@+2!U;G!A8VLH(DXB+"`D8G5F*2P@,CL*<F5A9"!?1D@L("1B=68L(#0[
M"B1D871A7W!O<R`]("AT96QL(%]&2"D@+2`T.PIM>2`E<F5Q=6ER95]L:7-T
M.PIW:&EL92`H)&)U9B!E<2`B1DE,12(I('L*<F5A9"!?1D@L("1B=68L(#0[
M"G)E860@7T9(+"`D8G5F+"!U;G!A8VLH(DXB+"`D8G5F*3L*;7D@)&9U;&QN
M86UE(#T@)&)U9CL*;W5T<RAQ<2A5;G!A8VMI;F<@9FEL92`B)&9U;&QN86UE
M(BXN+BDI.PIM>2`D8W)C(#T@*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[
M.'TI+WQ\("D@/R`D,2`Z('5N9&5F.PIM>2`H)&)A<V5N86UE+"`D97AT*2`]
M("@D8G5F(#U^(&U\*#\Z+BHO*3\H+BHI*%PN+BHI?"D["G)E860@7T9(+"`D
M8G5F+"`T.PIR96%D(%]&2"P@)&)U9BP@=6YP86-K*").(BP@)&)U9BD["FEF
M("AD969I;F5D*"1E>'0I(&%N9"`D97AT("%^("]<+B@_.G!M?'!L?&EX?&%L
M*20O:2D@>PIM>2`D9FEL96YA;64@/2!?=&5M<&9I;&4H(B1C<F,D97AT(BP@
M)&)U9BP@,#<U-2D["B1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9U;&QN86UE
M?2`]("1F:6QE;F%M93L*)%!!4CHZ2&5A=GDZ.D9U;&Q#86-H97LD9FEL96YA
M;65](#T@)&9U;&QN86UE.PI]"F5L<VEF("@@)&9U;&QN86UE(#U^(&U\7B\_
M<VAL:6(O?"!A;F0@9&5F:6YE9"`D14Y6>U!!4E]414U0?2`I('L*;7D@)&9I
M;&5N86UE(#T@7W1E;7!F:6QE*"(D8F%S96YA;64D97AT(BP@)&)U9BP@,#<U
M-2D["F]U=',H(E-(3$E".B`D9FEL96YA;65<;B(I.PI]"F5L<V4@>PHD<F5Q
M=6ER95]L:7-T>R1F=6QL;F%M97T@/0HD4$%2.CI(96%V>3HZ36]D=6QE0V%C
M:&5[)&9U;&QN86UE?2`]('L*8G5F(#T^("1B=68L"F-R8R`]/B`D8W)C+`IN
M86UE(#T^("1F=6QL;F%M92P*?3L*?0IR96%D(%]&2"P@)&)U9BP@-#L*?0IL
M;V-A;"!`24Y#(#T@*'-U8B!["FUY("@D<V5L9BP@)&UO9'5L92D@/2!`7SL*
M<F5T=7)N(&EF(')E9B`D;6]D=6QE(&]R("$D;6]D=6QE.PIM>2`D9FEL96YA
M;64@/2!D96QE=&4@)')E<75I<F5?;&ES='LD;6]D=6QE?2!\?"!D;R!["FUY
M("1K97D["F9O<F5A8V@@*&ME>7,@)7)E<75I<F5?;&ES="D@>PIN97AT('5N
M;&5S<R`O7%$D;6]D=6QE7$4D+SL*)&ME>2`]("1?.R!L87-T.PI]"F1E;&5T
M92`D<F5Q=6ER95]L:7-T>R1K97E](&EF(&1E9FEN960H)&ME>2D["GT@;W(@
M<F5T=7)N.PHD24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I;&5N86UE+R1M
M;V1U;&4B.PII9B`H)$5.5GM005)?0TQ%04Y](&%N9"!D969I;F5D*"9)3SHZ
M1FEL93HZ;F5W*2D@>PIM>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@
M;W(@9&EE("0A.PIB:6YM;V1E*"1F:"D["G!R:6YT("1F:"`D9FEL96YA;64M
M/GMB=69].PIS965K*"1F:"P@,"P@,"D["G)E='5R;B`D9F@["GT*96QS92![
M"FUY("1F:6QE;F%M92`](%]T96UP9FEL92@B)&9I;&5N86UE+3Y[8W)C?2YP
M;2(L("1F:6QE;F%M92T^>V)U9GTI.PIO<&5N(&UY("1F:"P@)SPG+"`D9FEL
M96YA;64@;W(@9&EE(")C86XG="!R96%D("1F:6QE;F%M93H@)"$B.PIB:6YM
M;V1E*"1F:"D["G)E='5R;B`D9F@["GT*9&EE(")";V]T<W1R87!P:6YG(&9A
M:6QE9#H@8V%N;F]T(&9I;F0@)&UO9'5L92%<;B(["GTL($!)3D,I.PIR97%U
M:7)E(%A33&]A9&5R.PIR97%U:7)E(%!!4CHZ2&5A=GD["G)E<75I<F4@0V%R
M<#HZ2&5A=GD["G)E<75I<F4@17AP;W)T97(Z.DAE879Y.PI005(Z.DAE879Y
M.CI?:6YI=%]D>6YA;&]A9&5R*"D["G)E<75I<F4@24\Z.D9I;&4["G=H:6QE
M("AM>2`D9FEL96YA;64@/2`H<V]R="!K97ES("5R97%U:7)E7VQI<W0I6S!=
M*2!["G5N;&5S<R`H)$E.0WLD9FEL96YA;65](&]R("1F:6QE;F%M92`]?B`O
M0E-$4$%.+RD@>PII9B`H)&9I;&5N86UE(#U^("]<+G!M8S\D+VDI('L*<F5Q
M=6ER92`D9FEL96YA;64["GT*96QS92!["F1O("1F:6QE;F%M92!U;FQE<W,@
M)&9I;&5N86UE(#U^("]S:71E8W5S=&]M:7IE7"YP;"0O.PI]"GT*9&5L971E
M("1R97%U:7)E7VQI<W1[)&9I;&5N86UE?3L*?0IL87-T('5N;&5S<R`D8G5F
M(&5Q(")02UPP,#-<,#`T(CL*)'-T87)T7W!O<R`]("AT96QL(%]&2"D@+2`T
M.PI]"FUY($!P87)?87)G<SL*;7D@*"1O=70L("1B=6YD;&4L("1L;V=F:"P@
M)&-A8VAE7VYA;64I.PID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S
M86YI=&EZ92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*)'%U
M:65T(#T@,"!U;FQE<W,@)$5.5GM005)?1$5"54=].PII9B`H(21S=&%R=%]P
M;W,@;W(@*"1!4D=66S!=(&5Q("<M+7!A<BUO<'1I;VYS)R`F)B!S:&EF="DI
M('L*;7D@)61I<W1?8VUD(#T@<7<H"G`@("!B;&EB7W1O7W!A<@II("`@:6YS
M=&%L;%]P87(*=2`@('5N:6YS=&%L;%]P87(*<R`@('-I9VY?<&%R"G8@("!V
M97)I9GE?<&%R"BD["FEF("A`05)'5B!A;F0@)$%21U9;,%T@97$@)RTM<F5U
M<V4G*2!["G-H:69T($!!4D=6.PHD14Y6>U!!4E]!4%!?4D554T5](#T@<VAI
M9G0@0$%21U8["GT*96QS92![(",@;F]R;6%L('!A<FP@8F5H879I;W5R"FUY
M($!A9&1?=&]?:6YC.PIW:&EL92`H0$%21U8I('L*)$%21U9;,%T@/7X@+UXM
M*%M!24U/0DQB<7!I=7-4=ETI*"XJ*2\@;W(@;&%S=#L*:68@*"0Q(&5Q("=)
M)RD@>PIP=7-H($!A9&1?=&]?:6YC+"`D,CL*?0IE;'-I9B`H)#$@97$@)TTG
M*2!["F5V86P@(G5S92`D,B(["GT*96QS:68@*"0Q(&5Q("=!)RD@>PIU;G-H
M:69T($!P87)?87)G<RP@)#(["GT*96QS:68@*"0Q(&5Q("=/)RD@>PHD;W5T
M(#T@)#(["GT*96QS:68@*"0Q(&5Q("=B)RD@>PHD8G5N9&QE(#T@)W-I=&4G
M.PI]"F5L<VEF("@D,2!E<2`G0B<I('L*)&)U;F1L92`]("=A;&PG.PI]"F5L
M<VEF("@D,2!E<2`G<2<I('L*)'%U:65T(#T@,3L*?0IE;'-I9B`H)#$@97$@
M)TPG*2!["F]P96X@)&QO9V9H+"`B/CXB+"`D,B!O<B!D:64@(EA86#H@0V%N
M;F]T(&]P96X@;&]G.B`D(2(["GT*96QS:68@*"0Q(&5Q("=4)RD@>PHD8V%C
M:&5?;F%M92`]("0R.PI]"G-H:69T*$!!4D=6*3L*:68@*&UY("1C;60@/2`D
M9&ES=%]C;61[)#%]*2!["F1E;&5T92`D14Y6>R=005)?5$5-4"=].PII;FET
M7VEN8R@I.PIR97%U:7)E(%!!4CHZ1&ES=#L*)GLB4$%2.CI$:7-T.CHD8VUD
M(GTH*2!U;FQE<W,@0$%21U8["B9[(E!!4CHZ1&ES=#HZ)&-M9")]*"1?*2!F
M;W(@0$%21U8["F5X:70["GT*?0IU;G-H:69T($!)3D,L($!A9&1?=&]?:6YC
M.PI]"GT*:68@*"1O=70I('L*>PIR97%U:7)E($E/.CI&:6QE.PIR97%U:7)E
M($%R8VAI=F4Z.EII<#L*?0IM>2`D<&%R(#T@<VAI9G0H0$%21U8I.PIM>2`D
M>FEP.PII9B`H9&5F:6YE9"`D<&%R*2!["D%R8VAI=F4Z.EII<#HZ<V5T0VAU
M;FM3:7IE*#$R."HQ,#(T*3L*;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D
M:64@(D-A;FYO="!F:6YD("<D<&%R)SH@)"$B.PIB:6YM;V1E*"1F:"D["F)L
M97-S*"1F:"P@)TE/.CI&:6QE)RD["B1Z:7`@/2!!<F-H:79E.CI::7`M/FYE
M=SL**"`D>FEP+3YR96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<&%R*2`]/2!!
M<F-H:79E.CI::7`Z.D%:7T]+*"D@*0IO<B!D:64@(E)E860@)R1P87(G(&5R
M<F]R.B`D(2(["GT*;7D@)65N=B`](&1O('L*:68@*"1Z:7`@86YD(&UY("1M
M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*)&UE=&$@/7X@
M<R\N*EYP87(Z)"\O;7,["B1M971A(#U^(',O7EQ3+BHO+VUS.PHD;65T82`]
M?B`O7B`@*%M>.ETK*3H@*"XK*20O;6<["GT*?3L*;&]C86P@)"\@/2!<-#L*
M:68@*&1E9FEN960@)'!A<BD@>PIO<&5N(%!!4BP@)SPG+"`D<&%R(&]R(&1I
M92`B)"$Z("1P87(B.PIB:6YM;V1E*%!!4BD["F1I92`B)'!A<B!I<R!N;W0@
M82!005(@9FEL92(@=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*?0I#
M<F5A=&50871H*"1O=70I(#L*;7D@)&9H(#T@24\Z.D9I;&4M/FYE=R@*)&]U
M="P*24\Z.D9I;&4Z.D]?0U)%050H*2!\($E/.CI&:6QE.CI/7U=23TY,62@I
M('P@24\Z.D9I;&4Z.D]?5%)53D,H*2P*,#<W-RP**2!O<B!D:64@)"$["F)I
M;FUO9&4H)&9H*3L*)"\@/2`H9&5F:6YE9"`D9&%T85]P;W,I(#\@7"1D871A
M7W!O<R`Z('5N9&5F.PIS965K(%]&2"P@,"P@,#L*;7D@)&QO861E<B`]('-C
M86QA<B`\7T9(/CL*:68@*"$D14Y6>U!!4E]615)"051)37T@86YD("1L;V%D
M97(@/7X@+UXH/SHC(7Q<0')E;2DO*2!["G)E<75I<F4@4$%2.CI&:6QT97(Z
M.E!O9%-T<FEP.PI005(Z.D9I;'1E<CHZ4&]D4W1R:7`M/FYE=RT^87!P;'DH
M7"1L;V%D97(L("0P*0I]"F9O<F5A8V@@;7D@)&ME>2`H<V]R="!K97ES("5E
M;G8I('L*;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*)'9A;"`](&5V
M86P@)'9A;"!I9B`D=F%L(#U^("]>6R<B72\["FUY("1M86=I8R`](")?7T5.
M5E]005)?(B`N('5C*"1K97DI("X@(E]?(CL*;7D@)'-E="`](")005)?(B`N
M('5C*"1K97DI("X@(CTD=F%L(CL*)&QO861E<B`]?B!S>R1M86=I8R@@*RE]
M>PHD;6%G:6,@+B`D<V5T("X@*"<@)R!X("AL96YG=&@H)#$I("T@;&5N9W1H
M*"1S970I*2D*?65G.PI]"B1F:"T^<')I;G0H)&QO861E<BD["B0O(#T@=6YD
M968["FEF("@D8G5N9&QE*2!["G)E<75I<F4@4$%2.CI(96%V>3L*4$%2.CI(
M96%V>3HZ7VEN:71?9'EN86QO861E<B@I.PII;FET7VEN8R@I.PIR97%U:7)E
M7VUO9'5L97,H*3L*;7D@0&EN8R`](&=R97`@>R`A+T)31%!!3B\@?0IG<F5P
M('L**"1B=6YD;&4@;F4@)W-I=&4G*2!O<@HH)%\@;F4@)$-O;F9I9SHZ0V]N
M9FEG>V%R8VAL:6)E>'!](&%N9`HD7R!N92`D0V]N9FEG.CI#;VYF:6=[<')I
M=FQI8F5X<'TI.PI]($!)3D,["FUY("5F:6QE<SL*)&9I;&5S>R1??2LK(&9O
M<B!`1'EN84QO861E<CHZ9&Q?<VAA<F5D7V]B:F5C=',L('9A;'5E<R`E24Y#
M.PIM>2`D;&EB7V5X="`]("1#;VYF:6<Z.D-O;F9I9WML:6)?97AT?3L*;7D@
M)7=R:71T96X["F9O<F5A8V@@*'-O<G0@:V5Y<R`E9FEL97,I('L*;7D@*"1N
M86UE+"`D9FEL92D["F9O<F5A8V@@;7D@)&1I<B`H0&EN8RD@>PII9B`H)&YA
M;64@/2`D4$%2.CI(96%V>3HZ1G5L;$-A8VAE>R1??2D@>PHD9FEL92`]("1?
M.PIL87-T.PI]"F5L<VEF("@O7BA<421D:7)<15PO*"XJ6UY#8UTI*5Q:+VDI
M('L**"1F:6QE+"`D;F%M92D@/2`H)#$L("0R*3L*;&%S=#L*?0IE;'-I9B`H
M;2%>+VQO861E<B];7B]=*R\H+BI;7D-C72E<6B$I('L*:68@*&UY("1R968@
M/2`D4$%2.CI(96%V>3HZ36]D=6QE0V%C:&5[)#%]*2!["B@D9FEL92P@)&YA
M;64I(#T@*"1R968L("0Q*3L*;&%S=#L*?0IE;'-I9B`H+68@(B1D:7(O)#$B
M*2!["B@D9FEL92P@)&YA;64I(#T@*"(D9&ER+R0Q(BP@)#$I.PIL87-T.PI]
M"GT*?0IN97AT('5N;&5S<R!D969I;F5D("1N86UE(&%N9"!N;W0@)'=R:71T
M96Y[)&YA;65]*RL["FYE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^
M("]<+EQ1)&QI8E]E>'1<120O.PIO=71S*"!J;VEN("(B+`IQ<2A086-K:6YG
M("(I+"!R968@)&9I;&4@/R`D9FEL92T^>VYA;65](#H@)&9I;&4L"G%Q*"(N
M+BXI"BD["FUY("1C;VYT96YT.PII9B`H<F5F*"1F:6QE*2D@>PHD8V]N=&5N
M="`]("1F:6QE+3Y[8G5F?3L*?0IE;'-E('L*;W!E;B!&24Q%+"`G/"<L("1F
M:6QE(&]R(&1I92`B0V%N)W0@;W!E;B`D9FEL93H@)"$B.PIB:6YM;V1E*$9)
M3$4I.PHD8V]N=&5N="`](#Q&24Q%/CL*8VQO<V4@1DE,13L*4$%2.CI&:6QT
M97(Z.E!O9%-T<FEP+3YN97<M/F%P<&QY*%PD8V]N=&5N="P@)&9I;&4I"FEF
M("$D14Y6>U!!4E]615)"051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX
M?&%L*20O:3L*4$%2.CI&:6QT97(Z.E!A=&-H0V]N=&5N="T^;F5W+3YA<'!L
M>2A<)&-O;G1E;G0L("1F:6QE+"`D;F%M92D["GT*;W5T<RAQ<2A7<FET=&5N
M(&%S("(D;F%M92(I*3L*)&9H+3YP<FEN="@B1DE,12(I.PHD9F@M/G!R:6YT
M*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PHD9F@M/G!R:6YT*'-P
M<FEN=&8H"B(E,#AX+R5S(BP@07)C:&EV93HZ6FEP.CIC;VUP=71E0U)#,S(H
M)&-O;G1E;G0I+"`D;F%M90HI*3L*)&9H+3YP<FEN="AP86-K*"=.)RP@;&5N
M9W1H*"1C;VYT96YT*2DI.PHD9F@M/G!R:6YT*"1C;VYT96YT*3L*?0I]"B1Z
M:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II<#L*)&-A8VAE7VYA
M;64@/2!S=6)S='(@)&-A8VAE7VYA;64L(#`L(#0P.PII9B`H(21C86-H95]N
M86UE(&%N9"!M>2`D;71I;64@/2`H<W1A="@D;W5T*2E;.5TI('L*;7D@)&-T
M>"`](&5V86P@>R!R97%U:7)E($1I9V5S=#HZ4TA!.R!$:6=E<W0Z.E-(02T^
M;F5W*#$I('T*?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E
M<W0Z.E-(03$M/FYE=R!]"GQ\(&5V86P@>R!R97%U:7)E($1I9V5S=#HZ340U
M.R!$:6=E<W0Z.DU$-2T^;F5W('T["FUY("1S:&%?=F5R<VEO;B`](&5V86P@
M>R`D1&EG97-T.CI32$$Z.E9%4E-)3TX@?2!\?"`P.PII9B`H)'-H85]V97)S
M:6]N(&5Q("<U+C,X)R!O<B`D<VAA7W9E<G-I;VX@97$@)S4N,SDG*2!["B1C
M='@M/F%D9&9I;&4H)&]U="P@(F(B*2!I9B`H)&-T>"D["GT*96QS92!["FEF
M("@D8W1X(&%N9"!O<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*8FEN;6]D92@D
M9F@I.PHD8W1X+3YA9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD8V%C
M:&5?;F%M92`]("1C='@@/R`D8W1X+3YH97AD:6=E<W0@.B`D;71I;64["GT*
M)&-A8VAE7VYA;64@+CT@(EPP(B!X("@T,2`M(&QE;F=T:"`D8V%C:&5?;F%M
M92D["B1C86-H95]N86UE("X](")#04-(12(["B1F:"T^<')I;G0H)&-A8VAE
M7VYA;64I.PHD9F@M/G!R:6YT*'!A8VLH)TXG+"`D9F@M/G1E;&P@+2!L96YG
M=&@H)&QO861E<BDI*3L*)&9H+3YP<FEN="@B7&Y005(N<&U<;B(I.PHD9F@M
M/F-L;W-E.PIC:&UO9"`P-S4U+"`D;W5T.PIE>&ET.PI]"GL*;&%S="!U;FQE
M<W,@9&5F:6YE9"`D<W1A<G1?<&]S.PI?9FEX7W!R;V=N86UE*"D["G)E<75I
M<F4@4$%2.PI005(Z.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["GL*<F5Q
M=6ER92!&:6QE.CI&:6YD.PIR97%U:7)E($%R8VAI=F4Z.EII<#L*?0IM>2`D
M>FEP(#T@07)C:&EV93HZ6FEP+3YN97<["FUY("1F:"`]($E/.CI&:6QE+3YN
M97<["B1F:"T^9F1O<&5N*&9I;&5N;RA?1D@I+"`G<B<I(&]R(&1I92`B)"$Z
M("1`(CL*)'II<"T^<F5A9$9R;VU&:6QE2&%N9&QE*"1F:"P@)'!R;V=N86UE
M*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@;W(@9&EE("(D(3H@)$`B.PIP
M=7-H($!005(Z.DQI8D-A8VAE+"`D>FEP.PHD4$%2.CI,:6)#86-H97LD<')O
M9VYA;65](#T@)'II<#L*)'%U:65T(#T@(21%3E9[4$%27T1%0E5'?3L*;W5T
M<RAQ<2A<)$5.5GM005)?5$5-4'T@/2`B)$5.5GM005)?5$5-4'TB*2D["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!]*2![(",@<VAO=6QD(&)E('-E="!A
M="!T:&ES('!O:6YT(0IF;W)E86-H(&UY("1M96UB97(@*"`D>FEP+3YM96UB
M97)S("D@>PIN97AT(&EF("1M96UB97(M/FES1&ER96-T;W)Y.PIM>2`D;65M
M8F5R7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*;F5X="!U;FQE<W,@)&UE
M;6)E<E]N86UE(#U^(&U["EX*+S]S:&QI8B\**#\Z)$-O;F9I9SHZ0V]N9FEG
M>W9E<G-I;VY]+RD_"B@_.B1#;VYF:6<Z.D-O;F9I9WMA<F-H;F%M97TO*3\*
M*%M>+UTK*0HD"GUX.PIM>2`D97AT<F%C=%]N86UE(#T@)#$["FUY("1D97-T
M7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%35!]+"`D
M97AT<F%C=%]N86UE*3L*:68@*"UF("1D97-T7VYA;64@)B8@+7,@7R`]/2`D
M;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI('L*;W5T<RAQ<2A3:VEP<&EN
M9R`B)&UE;6)E<E]N86UE(B!S:6YC92!I="!A;')E861Y(&5X:7-T<R!A="`B
M)&1E<W1?;F%M92(I*3L*?2!E;'-E('L*;W5T<RAQ<2A%>'1R86-T:6YG("(D
M;65M8F5R7VYA;64B('1O("(D9&5S=%]N86UE(BDI.PHD;65M8F5R+3YE>'1R
M86-T5&]&:6QE3F%M960H)&1E<W1?;F%M92D["F-H;6]D*#`U-34L("1D97-T
M7VYA;64I(&EF("1>3R!E<2`B:'!U>"(["GT*?0I]"GT*=6YL97-S("@D4$%2
M.CI,:6)#86-H97LD<')O9VYA;65]*2!["F1I92`\/"`B+B(@=6YL97-S($!!
M4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@6R`M36UO
M9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B0P(%L@+4)\+6(@
M72!;+4]O=71F:6QE72!S<F,N<&%R"BX*)$5.5GM005)?4%)/1TY!345](#T@
M)'!R;V=N86UE(#T@)#`@/2!S:&EF="A`05)'5BD["GT*<W5B($-R96%T95!A
M=&@@>PIM>2`H)&YA;64I(#T@0%\["G)E<75I<F4@1FEL93HZ0F%S96YA;64[
M"FUY("@D8F%S96YA;64L("1P871H+"`D97AT*2`]($9I;&4Z.D)A<V5N86UE
M.CIF:6QE<&%R<V4H)&YA;64L("@G7"XN*B<I*3L*<F5Q=6ER92!&:6QE.CI0
M871H.PI&:6QE.CI0871H.CIM:W!A=&@H)'!A=&@I('5N;&5S<R@M92`D<&%T
M:"D[(",@;6MP871H(&1I97,@=VET:"!E<G)O<@I]"G-U8B!R97%U:7)E7VUO
M9'5L97,@>PIR97%U:7)E(&QI8CL*<F5Q=6ER92!$>6YA3&]A9&5R.PIR97%U
M:7)E(&EN=&5G97(["G)E<75I<F4@<W1R:6-T.PIR97%U:7)E('=A<FYI;F=S
M.PIR97%U:7)E('9A<G,["G)E<75I<F4@0V%R<#L*<F5Q=6ER92!#87)P.CI(
M96%V>3L*<F5Q=6ER92!%<G)N;SL*<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD[
M"G)E<75I<F4@17AP;W)T97(["G)E<75I<F4@1F-N=&P["G)E<75I<F4@1FEL
M93HZ5&5M<#L*<F5Q=6ER92!&:6QE.CI3<&5C.PIR97%U:7)E(%A33&]A9&5R
M.PIR97%U:7)E($-O;F9I9SL*<F5Q=6ER92!)3SHZ2&%N9&QE.PIR97%U:7)E
M($E/.CI&:6QE.PIR97%U:7)E($-O;7!R97-S.CI:;&EB.PIR97%U:7)E($%R
M8VAI=F4Z.EII<#L*<F5Q=6ER92!005(["G)E<75I<F4@4$%2.CI(96%V>3L*
M<F5Q=6ER92!005(Z.D1I<W0["G)E<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T
M<FEP.PIR97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["G)E<75I
M<F4@871T<FEB=71E<SL*979A;"![(')E<75I<F4@0W=D('T["F5V86P@>R!R
M97%U:7)E(%=I;C,R('T["F5V86P@>R!R97%U:7)E(%-C86QA<CHZ571I;"!]
M.PIE=F%L('L@<F5Q=6ER92!!<F-H:79E.CI5;GII<#HZ0G5R<W0@?3L*979A
M;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE9$-A<'1U<F4@?3L*979A;"![
M(')E<75I<F4@4&5R;$E/.R!R97%U:7)E(%!E<FQ)3SHZ<V-A;&%R('T["F5V
M86P@>R!R97%U:7)E('5T9C@@?3L*?0IS=6(@7W-E=%]P87)?=&5M<"!["FEF
M("AD969I;F5D("1%3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]
M?B`O*"XK*2\I('L*)'!A<E]T96UP(#T@)#$["G)E='5R;CL*?0IF;W)E86-H
M(&UY("1P871H("@**&UA<"`D14Y6>R1??2P@<7<H(%!!4E]435!$25(@5$U0
M1$E2(%1%35!$25(@5$5-4"!435`@*2DL"G%W*"!#.EQ<5$5-4"`O=&UP("X@
M*0HI('L*;F5X="!U;FQE<W,@9&5F:6YE9"`D<&%T:"!A;F0@+60@)'!A=&@@
M86YD("UW("1P871H.PIM>2`D=7-E<FYA;64["FUY("1P=W5I9#L*979A;"![
M*"1P=W5I9"D@/2!G971P=W5I9"@D/BD@:68@9&5F:6YE9"`D/CM].PII9B`H
M(&1E9FEN960H)E=I;C,R.CI,;V=I;DYA;64I("D@>PHD=7-E<FYA;64@/2`F
M5VEN,S(Z.DQO9VEN3F%M93L*?0IE;'-I9B`H9&5F:6YE9"`D<'=U:60I('L*
M)'5S97)N86UE(#T@)'!W=6ED.PI]"F5L<V4@>PHD=7-E<FYA;64@/2`D14Y6
M>U5315).04U%?2!\?"`D14Y6>U5315)]('Q\("=365-414TG.PI]"B1U<V5R
M;F%M92`]?B!S+UQ7+U\O9SL*;7D@)'-T;7!D:7(@/2`B)'!A=&@D0V]N9FEG
M>U]D96QI;7UP87(M(BYU;G!A8VLH(D@J(BP@)'5S97)N86UE*3L*;6MD:7(@
M)'-T;7!D:7(L(#`W-34["FEF("@A)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D
M;71I;64@/2`H<W1A="@D<')O9VYA;64I*5LY72D@>PIO<&5N("AM>2`D9F@L
M("(\(BX@)'!R;V=N86UE*3L*<V5E:R`D9F@L("TQ."P@,CL*<WES<F5A9"`D
M9F@L(&UY("1B=68L(#8["FEF("@D8G5F(&5Q(")<,$-!0TA%(BD@>PIS965K
M("1F:"P@+34X+"`R.PIS>7-R96%D("1F:"P@)&)U9BP@-#$["B1B=68@/7X@
M<R]<,"\O9SL*)'-T;7!D:7(@+CT@(B1#;VYF:6=[7V1E;&EM?6-A8VAE+2(@
M+B`D8G5F.PI]"F5L<V4@>PIM>2`D8W1X(#T@979A;"![(')E<75I<F4@1&EG
M97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0I\?"!E=F%L('L@<F5Q
M=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ4TA!,2T^;F5W('T*?'P@979A
M;"![(')E<75I<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*
M;7D@)'-H85]V97)S:6]N(#T@979A;"![("1$:6=E<W0Z.E-(03HZ5D524TE/
M3B!]('Q\(#`["FEF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*)&-T>"T^861D9FEL92@D<')O9VYA;64L
M(")B(BD@:68@*"1C='@I.PI]"F5L<V4@>PII9B`H)&-T>"!A;F0@;W!E;BAM
M>2`D9F@L("(\)'!R;V=N86UE(BDI('L*8FEN;6]D92@D9F@I.PHD8W1X+3YA
M9&1F:6QE*"1F:"D["F-L;W-E*"1F:"D["GT*?0HD<W1M<&1I<B`N/2`B)$-O
M;F9I9WM?9&5L:6U]8V%C:&4M(B`N("@@)&-T>"`_("1C='@M/FAE>&1I9V5S
M="`Z("1M=&EM92`I.PI]"F-L;W-E*"1F:"D["GT*96QS92!["B1%3E9[4$%2
M7T-,14%.?2`](#$["B1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP
M+20D(CL*?0HD14Y6>U!!4E]414U0?2`]("1S=&UP9&ER.PIM:V1I<B`D<W1M
M<&1I<BP@,#<U-3L*;&%S=#L*?0HD<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!
M4E]414U0?2!A;F0@)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"G-U8B!?
M=&5M<&9I;&4@>PIM>2`H)&YA;64L("1C;VYT96YT<RP@)&UO9&4I(#T@0%\[
M"FUY("1F=6QL;F%M92`]("(D<&%R7W1E;7`O)&YA;64B.PIU;FQE<W,@*"UE
M("1F=6QL;F%M92D@>PIM>2`D=&5M<&YA;64@/2`B)&9U;&QN86UE+B0D(CL*
M;W!E;B!M>2`D9F@L("<^)RP@)'1E;7!N86UE(&]R(&1I92`B8V%N)W0@=W)I
M=&4@)'1E;7!N86UE.B`D(2(["F)I;FUO9&4@)&9H.PIP<FEN="`D9F@@)&-O
M;G1E;G1S.PIC;&]S92`D9F@["F-H;6]D("1M;V1E+"`D=&5M<&YA;64@:68@
M9&5F:6YE9"`D;6]D93L*<F5N86UE*"1T96UP;F%M92P@)&9U;&QN86UE*2!O
M<B!U;FQI;FLH)'1E;7!N86UE*3L*?0IR971U<FX@)&9U;&QN86UE.PI]"G-U
M8B!?<V5T7W!R;V=N86UE('L*:68@*&1E9FEN960@)$5.5GM005)?4%)/1TY!
M345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@+R@N*RDO*2!["B1P<F]G
M;F%M92`]("0Q.PI]"B1P<F]G;F%M92!\?#T@)#`["FEF("@D14Y6>U!!4E]4
M14U0?2!A;F0@:6YD97@H)'!R;V=N86UE+"`D14Y6>U!!4E]414U0?2D@/CT@
M,"D@>PHD<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["GT*:68@*"$D14Y6>U!!
M4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI
M;7TI(#X](#`I('L*:68@*&]P96X@;7D@)&9H+"`G/"<L("1P<F]G;F%M92D@
M>PIR971U<FX@:68@+7,@)&9H.PI]"FEF("@M<R`B)'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I('L*)'!R;V=N86UE("X]("1#;VYF:6=[7V5X97T["G)E='5R
M;CL*?0I]"F9O<F5A8V@@;7D@)&1I<B`H<W!L:70@+UQ1)$-O;F9I9WMP871H
M7W-E<'U<12\L("1%3E9[4$%42'TI('L*;F5X="!I9B!E>&ES=',@)$5.5GM0
M05)?5$5-4'T@86YD("1D:7(@97$@)$5.5GM005)?5$5-4'T["B1D:7(@/7X@
M<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PHH*"1P<F]G;F%M92`]("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(I+"!L87-T
M*0II9B`M<R`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M921#;VYF:6=[
M7V5X97TB.PHH*"1P<F]G;F%M92`]("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(BDL(&QA<W0I"FEF("US("(D9&ER)$-O;F9I9WM?9&5L:6U])'!R
M;V=N86UE(CL*?0I]"G-U8B!?9FEX7W!R;V=N86UE('L*)#`@/2`D<')O9VYA
M;64@?'P]("1%3E9[4$%27U!23T=.04U%?3L*:68@*&EN9&5X*"1P<F]G;F%M
M92P@)$-O;F9I9WM?9&5L:6U]*2`\(#`I('L*)'!R;V=N86UE(#T@(BXD0V]N
M9FEG>U]D96QI;7TD<')O9VYA;64B.PI]"FUY("1P=V0@/2`H9&5F:6YE9"`F
M0W=D.CIG971C=V0I(#\@0W=D.CIG971C=V0H*0HZ("@H9&5F:6YE9"`F5VEN
M,S(Z.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["F-H;VUP
M*"1P=V0I.PHD<')O9VYA;64@/7X@<R]>*#\]7"Y<+C]<421#;VYF:6=[7V1E
M;&EM?5Q%*2\D<'=D)$-O;F9I9WM?9&5L:6U]+SL*)$5.5GM005)?4%)/1TY!
M345](#T@)'!R;V=N86UE.PI]"G-U8B!?<&%R7VEN:71?96YV('L*:68@*"`D
M14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@>PIR971U<FX["GT@96QS
M92!["B1%3E9[4$%27TE.251)04Q)6D5$?2`](#(["GT*9F]R("AQ=R@@4U!!
M5TY%1"!414U0($-,14%.($1%0E5'($-!0TA%(%!23T=.04U%($%21T,@05)'
M5E\P("D@*2!["F1E;&5T92`D14Y6>R=005)?)RXD7WT["GT*9F]R("AQ=R\@
M5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PHD14Y6>R=005)?)RXD7WT@
M/2`D14Y6>R=005)?1TQ/0D%,7R<N)%]](&EF(&5X:7-T<R`D14Y6>R=005)?
M1TQ/0D%,7R<N)%]].PI]"FUY("1P87)?8VQE86X@/2`B7U]%3E9?4$%27T-,
M14%.7U\@("`@("`@("`@("`@("`B.PII9B`H)$5.5GM005)?5$5-4'TI('L*
M9&5L971E("1%3E9[4$%27T-,14%.?3L*?0IE;'-I9B`H(65X:7-T<R`D14Y6
M>U!!4E]'3$]"04Q?0TQ%04Y]*2!["FUY("1V86QU92`]('-U8G-T<B@D<&%R
M7V-L96%N+"`Q,B`K(&QE;F=T:"@B0TQ%04XB*2D["B1%3E9[4$%27T-,14%.
M?2`]("0Q(&EF("1V86QU92`]?B`O7E!!4E]#3$5!3CTH7%,K*2\["GT*?0IS
M=6(@;W5T<R!["G)E='5R;B!I9B`D<75I970["FEF("@D;&]G9F@I('L*<')I
M;G0@)&QO9V9H(")`7UQN(CL*?0IE;'-E('L*<')I;G0@(D!?7&XB.PI]"GT*
M<W5B(&EN:71?:6YC('L*<F5Q=6ER92!#;VYF:6<["G!U<V@@0$E.0RP@9W)E
M<"!D969I;F5D+"!M87`@)$-O;F9I9SHZ0V]N9FEG>R1??2P@<7<H"F%R8VAL
M:6)E>'`@<')I=FQI8F5X<"!S:71E87)C:&5X<"!S:71E;&EB97AP"G9E;F1O
M<F%R8VAE>'`@=F5N9&]R;&EB97AP"BD["GT*<&%C:V%G92!M86EN.PIR97%U
M:7)E(%!!4CL*=6YS:&EF="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^
M:6UP;W)T*$!P87)?87)G<RD["F1I92!Q<2AP87(N<&PZ($-A;B=T(&]P96X@
M<&5R;"!S8W)I<'0@(B1P<F]G;F%M92(Z($YO('-U8V@@9FEL92!O<B!D:7)E
M8W1O<GE<;BD*=6YL97-S("UE("1P<F]G;F%M93L*9&\@)'!R;V=N86UE.PI#
M3U)%.CIE>&ET*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I
M.PID:64@)$`@:68@)$`["GT["B0Z.E]?15)23U(@/2`D0"!I9B`D0#L*?0I#
M3U)%.CIE>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H
M7&0K*5PI+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["C$["E]?
M14Y$7U\*``!?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@("`@("`@(```````
M````<&5R;'AS:2YC`````1L#.\@````8````[(#__^0```"<A/__#`$``+2$
M___P!```S(?__R0!``#8G?__<`$``%Z>__^X`0``EI[__]`!```$G___^`$`
M`,"@__\\`@``_Z'__X`"``!_HO__I`(``*JB__^\`@``[J+__]0"``#IH___
M"`,``.ZC__\<`P``HJ7__V@#``"XI?__?`,``%>F__^4`P``^Z?__[@#```_
MJ/__T`,``%NH___H`P``\:C__R`$``",L?__@`0``-BT__^\!```%```````
M```!>E(``7@0`1L,!PB0`0``)````!P`````@/__L`,````.$$8.&$H/"W<(
M@``_&CLJ,R0B`````!0```!$````B(/__Q@``````````````$@```!<````
MH(;__PP6````0@X0CP)$#AB.`T(.((T$0@XHC`5!#C"&!D$..(,'1P[0!0/N
M%0XX00XP00XH0@X@0@X80@X00@X(``!$````J````&"<__^&`````$(.$(\"
M0@X8C@-"#B"-!$(.*(P%00XPA@9##CB#!T$.0`)K#CA$#C!!#BA"#B!"#AA"
M#A!"#@@4````\````)Z<__\X`````$0.(',."``D````"`$``+Z<__]N````
M`$$.$(8"00X8@P-'#C`"8@X800X000X(0````#`!```$G?__O`$```!"#A".
M`D(.&(T#0@X@C`1!#BB&!40.,(,&1PY``Z$!#C!!#BA!#B!"#AA"#A!"#@@`
M``!`````=`$``'R>__\_`0```$(.$(X"0@X8C0-"#B",!$$.*(8%00XP@P9'
M#M`!`R<!#C!!#BA!#B!"#AA"#A!"#@@``"````"X`0``=Y___X``````00X0
M@P)*#K`!`G,.$$$."````!0```#<`0``TY___RL`````00X05`X(`!0```#T
M`0``YI___T0`````00X0:@X(`#`````,`@``$J#___L`````0@X0C`)!#AB&
M`T$.((,$1PZP0`+K#B!!#AA!#A!"#@@````0````0`(``-F@__\%````````
M`$@```!4`@``RJ#__[0!````0@X0CP)"#AB.`T(.((T$0@XHC`5!#C"&!DL.
M.(,'2@[@(0.+`0XX00XP00XH0@X@0@X80@X00@X(```0````H`(``#*B__\6
M`````````!0```"T`@``-*+__Y\``````H<.$%0.""````#,`@``NZ+__Z0!
M````00X0@P)0#D`#D0$.$$$."````!0```#P`@``.Z3__T0`````2@X0<@X(
M`!0````(`P``9Z3__QP`````00X06@X(`#0````@`P``:Z3__Y8`````0@X0
MC`)##AB&`TL.((,$`G`*#AA(#A!$#@A%"T$.&$$.$$(."```7````%@#``#)
MI/__FP@```!"#A"/`E$.&(X#0@X@C01"#BB,!4$.,(8&00XX@P='#J"#`@,5
M"`ZH@P)*#K"#`DL.J(,"00Z@@P("10XX00XP00XH0@X@0@X80@X00@X(.```
M`+@#```$K?__3`,```!"#A"-`D(.&(P#00X@A@1!#BB#!4$.,`,^`PXH00X@
M00X80@X00@X(````,````/0#```4L/__3@````!!#A"&`D$.&(,#1`X@>@H.
M&$0.$$$."$4+00X800X000X(`"`````H!```O'___]8!````00X0@P)$#C`#
MS0$.$$,."```````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````````````````````````````````````````````````````````
M````````__________\``````````/__________````````````````````
M`````````````````````````````````````````````0`````````!````
M``````$`````````R`(````````/`````````#8$````````#```````````
M(`````````T`````````;%0```````#U_O]O`````)`"````````!0``````
M``"8#`````````8`````````@`,````````*`````````%0$````````"P``
M```````8`````````!4````````````````````#`````````-B]````````
M`@````````!P!0```````!0`````````!P`````````7`````````-`2````
M````!P````````#P$`````````@`````````X`$````````)`````````!@`
M````````&````````````````````/O__V\``````0``"`````#Y__]O````
M``<`````````````````````````````````````````````````````````
M```````````````````````````````````````````````````````````X
MO``````````````````````````````F(````````#8@````````1B``````
M``!6(````````&8@````````=B````````"&(````````)8@````````IB``
M``````"V(````````,8@````````UB````````#F(````````/8@````````
M!B$````````6(0```````"8A````````-B$```````!&(0```````%8A````
M````9B$```````!V(0```````(8A````````EB$```````"F(0```````+8A
M````````QB$```````#6(0```````.8A````````]B$````````&(@``````
M`!8B````````)B(````````V(@```````$8B````````5B(```````!F(@``
M`````'8B````````AB(```````"6(@```````*8B````````MB(```````#&
M(@```````-8B````````YB(```````#V(@````````8C````````%B,`````
M```F(P```````#8C````````1B,```````!6(P```````&8C````````=B,`
M``````"&(P```````)8C````````IB,```````"V(P``````````````````
M````````````````````````````````````````````````````````````
M````````````````P````````````````````````````````````````.)@
M````````VV`````````>8@```````/A@````````)F(`````````````````
M`/____\`````NV(```````!'0T,Z("A!;'!I;F4@."XR+C`I(#@N,BXP```N
M<VAS=')T86(`+FEN=&5R<``N9VYU+FAA<V@`+F1Y;G-Y;0`N9'EN<W1R`"YR
M96QA+F1Y;@`N<F5L82YP;'0`+FEN:70`+G!L="YG;W0`+G1E>'0`+F9I;FD`
M+G)O9&%T80`N96A?9G)A;65?:&1R`"YE:%]F<F%M90`N8W1O<G,`+F1T;W)S
M`"YD871A+G)E;"YR;P`N9'EN86UI8P`N9&%T80`N8G-S`"YC;VUM96YT````
M````````````````````````````````````````````````````````````
M``````````````````````````L````!`````@````````!P`@```````'`"
M````````&0````````````````````$````````````````````3````]O__
M;P(`````````D`(```````"0`@```````/```````````P`````````(````
M````````````````'0````L````"`````````(`#````````@`,````````8
M"0````````0````!````"``````````8`````````"4````#`````@``````
M``"8#````````)@,````````5`0```````````````````$`````````````
M```````M````!`````(`````````\!````````#P$````````.`!````````
M`P`````````(`````````!@`````````-P````0```!"`````````-`2````
M````T!(```````!P!0````````,````3````"``````````8`````````$$`
M```!````!@``````````(``````````@````````#0``````````````````
M``$````````````````````\`````0````8`````````$"`````````0(```
M`````+`#```````````````````0`````````!``````````1P````$````&
M`````````,`C````````P",````````8````````````````````"```````
M```(`````````%`````!````!@````````#8(P```````-@C````````E#``
M``````````````````$```````````````````!6`````0````8`````````
M;%0```````!L5`````````@````````````````````!````````````````
M````7`````$````"``````````!@`````````&`````````B/P``````````
M````````"````````````````````&0````!`````@`````````DGP``````
M`"2?````````S`````````````````````0```````````````````!R````
M`0````(`````````\)\```````#PGP```````$P$```````````````````(
M````````````````````?`````$````#`````````/"[````````\*L`````
M```0````````````````````"````````````````````(,````!`````P``
M````````O`````````"L````````$`````````````````````@`````````
M``````````"*`````0````,`````````$+P````````0K````````",`````
M```````````````0````````````````````EP````8````#`````````#B\
M````````.*P```````"@`0````````0`````````"``````````0````````
M`$L````!`````P````````#8O0```````-BM````````*`(`````````````
M``````@`````````"`````````"@`````0````,``````````,``````````
ML````````&`````````````````````@````````````````````I@````@`
M```#`````````&#`````````8+````````"H$```````````````````(```
M`````````````````*L````!````,````````````````````&"P````````
M&@````````````````````$``````````0`````````!`````P``````````
M``````````````!ZL````````+0````````````````````!````````````
&````````
